'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var mobx = require('mobx');
var mobxReactLite = require('mobx-react-lite');
var react = require('@use-gesture/react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

function isSuccess(result) {
    return result.success;
}
function isError(result) {
    return !result.success;
}
function successResult() {
    return { success: true };
}
function successValueResult(value) {
    return { success: true, value: value };
}
function errorResult(error) {
    return { success: false, error: error };
}
function errorValueResult(value, error) {
    return { success: false, error: error, value: value };
}

var addNodeCommand = function (node) { return ({
    execute: function (rootStore) {
        var result = rootStore.nodesStore.addNode(node, false);
        if (isSuccess(result)) {
            rootStore.selectionState.select(result.value, true);
        }
    },
}); };

function isPoint(value) {
    return (Array.isArray(value) &&
        value.length === 2 &&
        value.every(function (v) { return Number.isFinite(v); }));
}
var distanceBetweenPoints = function (a, b) {
    return Math.sqrt(Math.pow(a[0] - b[0], 2) + Math.pow(a[1] - b[1], 2));
};
var roundPoint = function (point) {
    return [Math.round(point[0]), Math.round(point[1])];
};
var addPoints = function () {
    var _a;
    var points = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        points[_i] = arguments[_i];
    }
    return (_a = points.reduce(function (prev, curr) {
        if (curr) {
            return [
                (prev ? prev[0] : 0) + curr[0],
                (prev ? prev[1] : 0) + curr[1]
            ];
        }
        else {
            return prev;
        }
    })) !== null && _a !== void 0 ? _a : [0, 0];
};
var subtractPoints = function () {
    var points = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        points[_i] = arguments[_i];
    }
    return points.reduce(function (prev, curr) {
        return curr ? [prev[0] - curr[0], prev[1] - curr[1]] : prev;
    });
};
var multiplyPoint = function (a, m) { return [
    a[0] * m,
    a[1] * m,
]; };
var arePointsEqual = function (a, b) {
    return a === b || (isPoint(a) && isPoint(b) && a[0] === b[0] && a[1] === b[1]);
};

var cloneSelectedNodesCommand = {
    execute: function (rootStore) {
        var nodeStates = rootStore.selectionState.selectedNodes.map(function (node) {
            var nodeState = node.export();
            nodeState.id = undefined;
            nodeState.label = nodeState.label;
            nodeState.position = addPoints(nodeState.position, [50, 50]);
            return nodeState;
        });
        rootStore.nodesStore.addNodes(nodeStates, false);
    },
};

var removeSelectedCommand = {
    execute: function (rootStore) {
        removeSelectedLinksCommand.execute(rootStore);
        removeSelectedNodesCommand.execute(rootStore);
    },
};
var removeSelectedNodesCommand = {
    execute: function (rootStore) {
        rootStore.nodesStore.removeNodes(rootStore.selectionState.selectedNodes.map(function (n) { return n.id; }));
    },
};
var removeSelectedLinksCommand = {
    execute: function (rootStore) {
        rootStore.linksStore.removeLinks(rootStore.selectionState.selectedLinks.map(function (n) { return n.id; }));
    },
};

var Callbacks = /** @class */ (function () {
    function Callbacks(rootStore) {
        var _this = this;
        Object.defineProperty(this, "_onNodesAddResult", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onNodesRemoveResult", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onNodePositionChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onNodeLabelChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onNodeTypeChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onNodeDataChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onNodeIsSelectionEnabledChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onNodeIsDragEnabledChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onDragStarted", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onDrag", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onDragEnded", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onImportedStateRendered", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onLinkValidation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onLinksAddResult", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onLinksRemoveResult", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onLinkingStarted", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_onLinkingEnded", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (callbacks) {
                _this._onLinkValidation = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onLinkValidation;
                _this._onNodesAddResult = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodesAddResult;
                _this._onNodesRemoveResult = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodesRemoveResult;
                _this._onNodePositionChanged = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodePositionChanged;
                _this._onNodeLabelChanged = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodeLabelChanged;
                _this._onNodeTypeChanged = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodeTypeChanged;
                _this._onNodeDataChanged = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodeDataChanged;
                _this._onNodeIsSelectionEnabledChanged = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodeIsSelectionEnabledChanged;
                _this._onNodeIsDragEnabledChanged = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onNodeIsDragEnabledChanged;
                _this._onDragStarted = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onDragStarted;
                _this._onDrag = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onDrag;
                _this._onDragEnded = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onDragEnded;
                _this._onImportedStateRendered = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onImportedStateRendered;
                _this._onLinksAddResult = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onLinksAddResult;
                _this._onLinksRemoveResult = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onLinksRemoveResult;
                _this._onLinkingStarted = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onLinkingStarted;
                _this._onLinkingEnded = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onLinkingEnded;
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () { return ({
                onNodesAddResult: _this._onNodesAddResult,
                onNodesRemoveResult: _this._onNodesRemoveResult,
                onNodePositionChanged: _this._onNodePositionChanged,
                onNodeLabelChanged: _this._onNodeLabelChanged,
                onNodeTypeChanged: _this._onNodeTypeChanged,
                onNodeDataChanged: _this._onNodeDataChanged,
                onNodeIsSelectionEnabledChanged: _this._onNodeIsSelectionEnabledChanged,
                onNodeIsDragEnabledChanged: _this._onNodeIsDragEnabledChanged,
                onDragStarted: _this._onDragStarted,
                onDrag: _this._onDrag,
                onDragEnded: _this._onDragEnded,
                onImportedStateRendered: _this._onImportedStateRendered,
                onLinkValidation: _this._onLinkValidation,
                onLinksAddResult: _this._onLinksAddResult,
                onLinksRemoveResult: _this._onLinksRemoveResult,
                onLinkingStarted: _this._onLinkingStarted,
                onLinkingEnded: _this._onLinkingEnded,
            }); }
        });
        Object.defineProperty(this, "linkValidation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onLinkValidation)
                    return _this._onLinkValidation(info, _this._rootStore);
                else
                    return true;
            }
        });
        Object.defineProperty(this, "nodesAdded", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onNodesAddResult &&
                    (info.addedNodes.length > 0 || info.failedToAddNodes.length > 0)) {
                    _this._onNodesAddResult(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "nodesRemoved", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onNodesRemoveResult &&
                    (info.removedNodes.length > 0 || info.failedToRemoveNodeIds.length > 0)) {
                    _this._onNodesRemoveResult(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "nodePositionChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, change) {
                if (_this._onNodePositionChanged) {
                    _this._onNodePositionChanged({
                        oldValue: change.oldValue,
                        newValue: change.newValue,
                        node: node,
                    }, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "nodeTypeChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, change) {
                if (_this._onNodeTypeChanged) {
                    _this._onNodeTypeChanged({
                        oldValue: change.oldValue,
                        newValue: change.newValue,
                        node: node,
                    }, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "nodeLabelChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, change) {
                if (_this._onNodeLabelChanged) {
                    _this._onNodeLabelChanged({
                        oldValue: change.oldValue,
                        newValue: change.newValue,
                        node: node,
                    }, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "nodeDataChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, change) {
                if (_this._onNodeDataChanged) {
                    _this._onNodeDataChanged({
                        oldValue: change.oldValue,
                        newValue: change.newValue,
                        node: node,
                    }, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "nodeIsSelectionEnabledChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, change) {
                if (_this._onNodeIsSelectionEnabledChanged) {
                    _this._onNodeIsSelectionEnabledChanged({
                        oldValue: change.oldValue,
                        newValue: change.newValue,
                        node: node,
                    }, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "nodeIsDragEnabledChanged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, change) {
                if (_this._onNodeIsDragEnabledChanged) {
                    _this._onNodeIsDragEnabledChanged({
                        oldValue: change.oldValue,
                        newValue: change.newValue,
                        node: node,
                    }, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "dragStarted", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onDragStarted) {
                    _this._onDragStarted(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "drag", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onDrag) {
                    _this._onDrag(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "dragEnded", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onDragEnded) {
                    _this._onDragEnded(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "importedStateRendered", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                if (_this._rootStore.diagramSettings.zoomToFitSettings.callOnImportState) {
                    _this._rootStore.diagramState.zoomToFit();
                }
                if (_this._onImportedStateRendered) {
                    _this._onImportedStateRendered(_this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "linksAdded", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onLinksAddResult &&
                    (info.addedLinks.length > 0 || info.failedToAddLinks.length > 0)) {
                    _this._onLinksAddResult(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "linksRemoved", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onLinksRemoveResult &&
                    (info.removedLinks.length > 0 || info.failedToRemoveLinkIds.length > 0)) {
                    _this._onLinksRemoveResult(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "linkingStarted", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onLinkingStarted) {
                    _this._onLinkingStarted(info, _this._rootStore);
                }
            }
        });
        Object.defineProperty(this, "linkingEnded", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (info) {
                if (_this._onLinkingEnded) {
                    _this._onLinkingEnded(info, _this._rootStore);
                }
            }
        });
        this._rootStore = rootStore;
        this.import();
    }
    return Callbacks;
}());

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

var SvgBackground = mobxReactLite.observer(function (_a) {
    var diagramOffset = _a.diagramOffset, diagramZoom = _a.diagramZoom, settings = _a.settings;
    var finalSettings = settings !== null && settings !== void 0 ? settings : defaultSettings$2;
    var backgroundImage = React.useMemo(function () {
        return finalSettings.imageGenerator
            ? finalSettings.imageGenerator(100 * diagramZoom, 100 * diagramZoom)
            : undefined;
    }, [finalSettings, finalSettings.imageGenerator, diagramZoom]);
    return (React__default["default"].createElement("div", { className: 'react_fast_diagram_Background', style: {
            backgroundColor: finalSettings.color,
            backgroundImage: backgroundImage,
            backgroundPosition: diagramOffset[0] + "px " + diagramOffset[1] + "px",
        } }));
});
var gridImageGenerator = function (width, height, sizeMultiplicator, linesColor, linesOpacity) {
    linesColor = linesColor.replace('#', '%23');
    return "url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='" + width * sizeMultiplicator + "' height='" + height * sizeMultiplicator + "' viewBox='0 0 100 100'%3E%3Cg fill-rule='evenodd'%3E%3Cg fill='" + linesColor + "' fill-opacity='" + linesOpacity + "'%3E%3Cpath opacity='.5' d='M96 95h4v1h-4v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9zm-1 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm9-10v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm9-10v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm9-10v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9z'/%3E%3Cpath d='M6 5V0H5v5H0v1h5v94h1V6h94V5H6z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E\")";
};
var createGridImageGenerator = function (sizeMultiplicator, linesColor, linesOpacity) { return function (width, height) {
    return gridImageGenerator(width, height, sizeMultiplicator, linesColor, linesOpacity);
}; };
var dotsImageGenerator = function (width, height, sizeMultiplicator, dotsColor, dotsOpacity, dotsRadius) {
    sizeMultiplicator = 0.1 * sizeMultiplicator;
    dotsColor = dotsColor.replace('#', '%23');
    return "url(\"data:image/svg+xml,%3Csvg width='" + width * sizeMultiplicator + "' height='" + height * sizeMultiplicator + "' viewBox='0 0 20 20' xmlns='http://www.w3.org/2000/svg'%3E%3Cg fill='" + dotsColor + "' fill-opacity='" + dotsOpacity + "' fill-rule='evenodd'%3E%3Ccircle cx='3' cy='3' r='" + dotsRadius + "'/%3E%3Ccircle cx='13' cy='13' r='" + dotsRadius + "'/%3E%3C/g%3E%3C/svg%3E\")";
};
var createDotsImageGenerator = function (sizeMultiplicator, dotsColor, dotsOpacity, dotsRadius) { return function (width, height) {
    return dotsImageGenerator(width, height, sizeMultiplicator, dotsColor, dotsOpacity, dotsRadius);
}; };
var crossesImageGenerator = function (width, height, sizeMultiplicator, color, opacity) {
    color = color.replace('#', '%23');
    return "url(\"data:image/svg+xml,%3Csvg width='" + width * sizeMultiplicator + "' height='" + height * sizeMultiplicator + "' viewBox='0 0 60 60' xmlns='http://www.w3.org/2000/svg'%3E%3Cg fill='none' fill-rule='evenodd'%3E%3Cg fill='" + color + "' fill-opacity='" + opacity + "'%3E%3Cpath d='M36 34v-4h-2v4h-4v2h4v4h2v-4h4v-2h-4zm0-30V0h-2v4h-4v2h4v4h2V6h4V4h-4zM6 34v-4H4v4H0v2h4v4h2v-4h4v-2H6zM6 4V0H4v4H0v2h4v4h2V6h4V4H6z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E\")";
};
var createCrossesImageGenerator = function (sizeMultiplicator, color, opacity) { return function (width, height) {
    return crossesImageGenerator(width, height, sizeMultiplicator, color, opacity);
}; };
var defaultSettings$2 = {
    imageGenerator: createCrossesImageGenerator(0.2, '#858585', 0.1),
    color: '#ffffff',
};
var createSvgBackground = function (settings) {
    var finalSettings = __assign(__assign({}, defaultSettings$2), (settings ? settings : {}));
    return {
        component: SvgBackground,
        settings: finalSettings,
    };
};

var VisualComponentState = /** @class */ (function () {
    function VisualComponentState(component) {
        var _this = this;
        Object.defineProperty(this, "_component", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_settings", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: null
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newComponent) {
                var _a;
                if ('component' in newComponent) {
                    _this._component = newComponent.component;
                    _this._settings = (_a = newComponent.settings) !== null && _a !== void 0 ? _a : null;
                }
                else {
                    _this._component = newComponent;
                    _this._settings = null;
                }
            }
        });
        this.import(component);
        mobx.makeObservable(this, {
            _component: mobx.observable.ref,
            _settings: mobx.observable.ref,
            component: mobx.computed,
            settings: mobx.computed,
            import: mobx.action,
        });
    }
    Object.defineProperty(VisualComponentState.prototype, "component", {
        get: function () {
            return this._component;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(VisualComponentState.prototype, "settings", {
        get: function () {
            return this._settings;
        },
        enumerable: false,
        configurable: true
    });
    return VisualComponentState;
}());

var VisualComponentWithDefault = /** @class */ (function () {
    function VisualComponentWithDefault(defaultComponent) {
        var _this = this;
        Object.defineProperty(this, "_innerComponent", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_defaultComponent", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newComponent) {
                _this._innerComponent = newComponent
                    ? new VisualComponentState(newComponent)
                    : _this._defaultComponent;
            }
        });
        this._innerComponent = new VisualComponentState(defaultComponent);
        this._defaultComponent = this._innerComponent;
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(VisualComponentWithDefault.prototype, "component", {
        get: function () {
            return this._innerComponent.component;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(VisualComponentWithDefault.prototype, "settings", {
        get: function () {
            return this._innerComponent.settings;
        },
        enumerable: false,
        configurable: true
    });
    return VisualComponentWithDefault;
}());

// Icons from https://material-ui.com/components/material-icons/
var RubbishBinIcon = function () { return (React__default["default"].createElement("svg", { viewBox: '0 0 24 24' },
    React__default["default"].createElement("path", { d: "M6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zm2.46-7.12l1.41-1.41L12 12.59l2.12-2.12 1.41 1.41L13.41 14l2.12 2.12-1.41 1.41L12 15.41l-2.12 2.12-1.41-1.41L10.59 14l-2.13-2.12zM15.5 4l-1-1h-5l-1 1H5v2h14V4z" }))); };
var CopyIcon = function () { return (React__default["default"].createElement("svg", { viewBox: '0 0 24 24' },
    React__default["default"].createElement("path", { d: 'M16 1H4c-1.1 0-2 .9-2 2v14h2V3h12V1zm-1 4H8c-1.1 0-1.99.9-1.99 2L6 21c0 1.1.89 2 1.99 2H19c1.1 0 2-.9 2-2V11l-6-6zM8 21V7h6v5h5v9H8z' }))); };
var FilterCenterFocusIcon = function () { return (React__default["default"].createElement("svg", { viewBox: '0 0 24 24' },
    React__default["default"].createElement("path", { d: "M5 15H3v4c0 1.1.9 2 2 2h4v-2H5v-4zM5 5h4V3H5c-1.1 0-2 .9-2 2v4h2V5zm14-2h-4v2h4v4h2V5c0-1.1-.9-2-2-2zm0 16h-4v2h4c1.1 0 2-.9 2-2v-4h-2v4zM12 9c-1.66 0-3 1.34-3 3s1.34 3 3 3 3-1.34 3-3-1.34-3-3-3z" }))); };
var LockIcon = function () { return (React__default["default"].createElement("svg", { viewBox: '0 0 24 24' },
    React__default["default"].createElement("path", { d: "M18 8h-1V6c0-2.76-2.24-5-5-5S7 3.24 7 6v2H6c-1.1 0-2 .9-2 2v10c0 1.1.9 2 2 2h12c1.1 0 2-.9 2-2V10c0-1.1-.9-2-2-2zm-6 9c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2zm3.1-9H8.9V6c0-1.71 1.39-3.1 3.1-3.1 1.71 0 3.1 1.39 3.1 3.1v2z" }))); };
var UnlockIcon = function () { return (React__default["default"].createElement("svg", { viewBox: '0 0 24 24' },
    React__default["default"].createElement("path", { d: "M12 17c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm6-9h-1V6c0-2.76-2.24-5-5-5S7 3.24 7 6h1.9c0-1.71 1.39-3.1 3.1-3.1 1.71 0 3.1 1.39 3.1 3.1v2H6c-1.1 0-2 .9-2 2v10c0 1.1.9 2 2 2h12c1.1 0 2-.9 2-2V10c0-1.1-.9-2-2-2zm0 12H6V10h12v10z" }))); };

function isNumber(value) {
    return Number.isFinite(value);
}
function isObject(value) {
    return value != null && typeof value == 'object' && !Array.isArray(value);
}
function isBoolean(value) {
    return value != null && typeof value == 'boolean';
}
function clampValue(value, interval) {
    return Math.min(Math.max(value, interval[0]), interval[1]);
}
function deepCopy(value) {
    return JSON.parse(JSON.stringify(value));
}
function combineArrays() {
    var arrays = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        arrays[_i] = arguments[_i];
    }
    var combined = [];
    arrays.forEach(function (a) { return a === null || a === void 0 ? void 0 : a.forEach(function (v) { return v && combined.push(v); }); });
    return combined;
}

var MiniControlDefault = mobxReactLite.observer(function (_a) {
    var _b = _a.rootStore, commandExecutor = _b.commandExecutor, diagramState = _b.diagramState, diagramSettings = _b.diagramSettings, selectionState = _b.selectionState, settings = _a.settings;
    var finalSettings = settings !== null && settings !== void 0 ? settings : defaultSettings$1;
    var className = React.useMemo(function () {
        return combineArrays(['react_fast_diagram_MiniControl_Default'], finalSettings === null || finalSettings === void 0 ? void 0 : finalSettings.classes).join(' ');
    }, [finalSettings]);
    var style = React.useMemo(function () { return (__assign(__assign({}, getOffsetStyles(finalSettings)), finalSettings === null || finalSettings === void 0 ? void 0 : finalSettings.style)); }, [finalSettings]);
    if (Object.values(finalSettings.buttons).every(function (v) { return v === false; }))
        return null;
    return (React__default["default"].createElement("div", { className: className, style: style },
        finalSettings.buttons.deleteSelection &&
            selectionState.selectedItems.length > 0 && (React__default["default"].createElement(Button, { size: finalSettings.buttonsSize, onClick: function () { return commandExecutor.execute(removeSelectedCommand); } },
            React__default["default"].createElement(RubbishBinIcon, null))),
        finalSettings.buttons.cloneSelectedNodes &&
            selectionState.selectedNodes.length > 0 && (React__default["default"].createElement(Button, { size: finalSettings.buttonsSize, onClick: function () { return commandExecutor.execute(cloneSelectedNodesCommand); } },
            React__default["default"].createElement(CopyIcon, null))),
        finalSettings.buttons.zoomIn && (React__default["default"].createElement(Button, { size: finalSettings.buttonsSize, onClick: diagramState.zoomIn, children: '+' })),
        finalSettings.buttons.zoomOut && (React__default["default"].createElement(Button, { size: finalSettings.buttonsSize, onClick: diagramState.zoomOut, children: '-' })),
        finalSettings.buttons.zoomToFit && (React__default["default"].createElement(Button, { size: finalSettings.buttonsSize, onClick: diagramState.zoomToFit },
            React__default["default"].createElement(FilterCenterFocusIcon, null))),
        finalSettings.buttons.lockUnlockPointerInteractions && (React__default["default"].createElement(Button, { size: finalSettings.buttonsSize, onClick: function () {
                if (diagramSettings.userInteraction.arePointerInteractionsDisabled)
                    diagramSettings.userInteraction.enableAllPointerInteractions(true);
                else
                    diagramSettings.userInteraction.disableAllPointerInteractions(true);
            } }, diagramSettings.userInteraction.arePointerInteractionsDisabled ? (React__default["default"].createElement(LockIcon, null)) : (React__default["default"].createElement(UnlockIcon, null))))));
});
function getOffsetStyles(settings) {
    return {
        top: settings.position == 'left-top' || settings.position == 'right-top'
            ? settings.parentOffset
            : undefined,
        right: settings.position == 'right-bottom' || settings.position == 'right-top'
            ? settings.parentOffset
            : undefined,
        bottom: settings.position == 'left-bottom' || settings.position == 'right-bottom'
            ? settings.parentOffset
            : undefined,
        left: settings.position == 'left-top' || settings.position == 'left-bottom'
            ? settings.parentOffset
            : undefined,
    };
}
var Button = function (props) { return (React__default["default"].createElement("button", { onClick: props.onClick, className: 'react_fast_diagram_MiniControl_Btn', style: {
        width: props.size + 'px',
        height: props.size + 'px',
        padding: 5,
    } }, props.children)); };
var createDefaultMiniControl = function (settings) {
    var finalSettings = __assign(__assign({}, defaultSettings$1), (settings ? settings : {}));
    return {
        component: MiniControlDefault,
        settings: finalSettings,
    };
};
var defaultSettings$1 = {
    position: 'left-bottom',
    buttonsSize: 30,
    buttons: {
        zoomIn: true,
        zoomOut: true,
        deleteSelection: true,
        cloneSelectedNodes: true,
        zoomToFit: true,
        lockUnlockPointerInteractions: true,
    },
    parentOffset: 20,
};

var UserInteractionSettings = /** @class */ (function () {
    function UserInteractionSettings() {
        var _this = this;
        Object.defineProperty(this, "_diagramZoom", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_diagramPan", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_nodeDrag", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_portConnection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_nodeSelection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_linkSelection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_multiselectionKey", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_disableAllPointerInteractionsCounter", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (obj) {
                var _a, _b, _c, _d, _e, _f, _g;
                _this._diagramZoom = (_a = obj === null || obj === void 0 ? void 0 : obj.diagramZoom) !== null && _a !== void 0 ? _a : true;
                _this._diagramPan = (_b = obj === null || obj === void 0 ? void 0 : obj.diagramPan) !== null && _b !== void 0 ? _b : true;
                _this._nodeDrag = (_c = obj === null || obj === void 0 ? void 0 : obj.nodeDrag) !== null && _c !== void 0 ? _c : true;
                _this._portConnection = (_d = obj === null || obj === void 0 ? void 0 : obj.portConnection) !== null && _d !== void 0 ? _d : true;
                _this._nodeSelection = (_e = obj === null || obj === void 0 ? void 0 : obj.nodeSelection) !== null && _e !== void 0 ? _e : true;
                _this._linkSelection = (_f = obj === null || obj === void 0 ? void 0 : obj.linkSelection) !== null && _f !== void 0 ? _f : true;
                _this._multiselectionKey = (_g = obj === null || obj === void 0 ? void 0 : obj.multiselectionKey) !== null && _g !== void 0 ? _g : 'shift';
                _this._disableAllPointerInteractionsCounter =
                    (obj === null || obj === void 0 ? void 0 : obj.disableAllMouseAndTouchInteractions) ? 1 : 0;
            }
        });
        Object.defineProperty(this, "disableAllPointerInteractions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (force) {
                if (force === void 0) { force = false; }
                _this._disableAllPointerInteractionsCounter = force
                    ? 1
                    : _this._disableAllPointerInteractionsCounter + 1;
            }
        });
        Object.defineProperty(this, "enableAllPointerInteractions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (force) {
                if (force === void 0) { force = false; }
                _this._disableAllPointerInteractionsCounter = force
                    ? 0
                    : _this._disableAllPointerInteractionsCounter - 1;
            }
        });
        Object.defineProperty(this, "isCallbackMultiselectionActivated", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (shiftKey, altKey, ctrlKey, metaKey) {
                switch (_this.multiselectionKey) {
                    case 'alt':
                        return altKey;
                    case 'ctrl':
                        return ctrlKey;
                    case 'meta':
                        return metaKey;
                    case 'shift':
                        return shiftKey;
                    default:
                        return false;
                }
            }
        });
        this.import();
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(UserInteractionSettings.prototype, "diagramZoom", {
        get: function () {
            return this._diagramZoom;
        },
        set: function (value) {
            this._diagramZoom = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(UserInteractionSettings.prototype, "diagramPan", {
        get: function () {
            return this._diagramPan;
        },
        set: function (value) {
            this._diagramPan = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(UserInteractionSettings.prototype, "nodeDrag", {
        get: function () {
            return this._nodeDrag;
        },
        set: function (value) {
            this._nodeDrag = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(UserInteractionSettings.prototype, "portConnection", {
        get: function () {
            return this._portConnection;
        },
        set: function (value) {
            this._portConnection = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(UserInteractionSettings.prototype, "nodeSelection", {
        get: function () {
            return this._nodeSelection;
        },
        set: function (value) {
            this._nodeSelection = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(UserInteractionSettings.prototype, "linkSelection", {
        get: function () {
            return this._linkSelection;
        },
        set: function (value) {
            this._linkSelection = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(UserInteractionSettings.prototype, "multiselectionKey", {
        get: function () {
            return this._multiselectionKey;
        },
        set: function (value) {
            this._multiselectionKey = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(UserInteractionSettings.prototype, "arePointerInteractionsDisabled", {
        get: function () {
            return this._disableAllPointerInteractionsCounter > 0;
        },
        enumerable: false,
        configurable: true
    });
    return UserInteractionSettings;
}());

var DiagramSettings = /** @class */ (function () {
    function DiagramSettings() {
        var _this = this;
        Object.defineProperty(this, "_backgroundComponentState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_miniControlComponentState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_zoomInterval", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: defaultZoomInterval
        });
        Object.defineProperty(this, "_zoomToFitSettings", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: defaultZoomToFitSettings
        });
        Object.defineProperty(this, "_userInteraction", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (obj) {
                _this._backgroundComponentState.import(obj === null || obj === void 0 ? void 0 : obj.backgroundComponent);
                _this._miniControlComponentState.import(obj === null || obj === void 0 ? void 0 : obj.miniControlComponent);
                _this.setZoomInterval(obj === null || obj === void 0 ? void 0 : obj.zoomInterval);
                _this._zoomToFitSettings = __assign(__assign({}, defaultZoomToFitSettings), obj === null || obj === void 0 ? void 0 : obj.zoomToFitSettings);
                _this._userInteraction.import(obj === null || obj === void 0 ? void 0 : obj.userInteraction);
            }
        });
        Object.defineProperty(this, "setZoomInterval", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._zoomInterval = value !== null && value !== void 0 ? value : defaultZoomInterval;
            }
        });
        this._backgroundComponentState = new VisualComponentWithDefault(createSvgBackground());
        this._miniControlComponentState = new VisualComponentWithDefault(createDefaultMiniControl());
        this._userInteraction = new UserInteractionSettings();
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(DiagramSettings.prototype, "backgroundComponentState", {
        get: function () {
            return this._backgroundComponentState;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramSettings.prototype, "miniControlComponentState", {
        get: function () {
            return this._miniControlComponentState;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramSettings.prototype, "zoomInterval", {
        get: function () {
            return this._zoomInterval;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramSettings.prototype, "zoomToFitSettings", {
        get: function () {
            return this._zoomToFitSettings;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramSettings.prototype, "userInteraction", {
        get: function () {
            return this._userInteraction;
        },
        enumerable: false,
        configurable: true
    });
    return DiagramSettings;
}());
var defaultZoomInterval = [0.1, 3];
var defaultZoomToFitSettings = {
    padding: [30, 30],
    zoomInterval: [0.1, 1.5],
    callOnImportState: true
};

var HtmlElementRefState = /** @class */ (function () {
    function HtmlElementRefState(initValue, diagramState) {
        var _this = this;
        Object.defineProperty(this, "_diagramState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_currentInternal", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_triggerSizePositionRecalculation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: 0
        });
        Object.defineProperty(this, "getDataAttribute", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (name) {
                if (_this.current) {
                    return _this.current.getAttribute(name);
                }
                return null;
            }
        });
        Object.defineProperty(this, "recalculateSizeAndPosition", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                _this._triggerSizePositionRecalculation += 1;
            }
        });
        this._currentInternal = initValue;
        mobx.makeAutoObservable(this, {
            sizeExcludingZoom: mobx.computed({ keepAlive: true }),
            positionExcludingZoom: mobx.computed({ keepAlive: true }),
            boundingRect: mobx.computed({ keepAlive: true }),
        });
        this._diagramState = diagramState;
    }
    Object.defineProperty(HtmlElementRefState.prototype, "current", {
        get: function () {
            return this._currentInternal;
        },
        set: function (value) {
            this._currentInternal = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HtmlElementRefState.prototype, "sizeExcludingZoom", {
        /**
         * Size excluding diagram zoom.
         */
        get: function () {
            if (this.boundingRect && this.boundingRect.diagramZoom) {
                return multiplyPoint(this.boundingRect.size, 1 / this.boundingRect.diagramZoom);
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HtmlElementRefState.prototype, "positionExcludingZoom", {
        /**
         * Position excluding diagram zoom.
         */
        get: function () {
            if (this.boundingRect && this.boundingRect.diagramZoom) {
                return multiplyPoint(this.boundingRect.position, 1 / this.boundingRect.diagramZoom);
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HtmlElementRefState.prototype, "boundingRect", {
        get: function () {
            this._triggerSizePositionRecalculation | 1;
            if (this.current) {
                var rect = this.current.getBoundingClientRect();
                var zoom = this._diagramState.getRenderedZoom();
                return {
                    position: [rect.x, rect.y],
                    size: [rect.width, rect.height],
                    diagramZoom: zoom,
                };
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    return HtmlElementRefState;
}());

var DiagramState = /** @class */ (function () {
    function DiagramState(rootStore) {
        var _this = this;
        Object.defineProperty(this, "_offset", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_zoom", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_ref", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_renderImportedRequestId", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: -1
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (state) {
                _this.setOffset(state === null || state === void 0 ? void 0 : state.offset);
                _this.setZoom(state === null || state === void 0 ? void 0 : state.zoom);
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                return deepCopy({
                    offset: _this._offset,
                    zoom: _this._zoom,
                });
            }
        });
        Object.defineProperty(this, "setOffset", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newOffset) {
                _this._offset = newOffset !== null && newOffset !== void 0 ? newOffset : [0, 0];
            }
        });
        Object.defineProperty(this, "setZoom", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newZoom) {
                _this._zoom = clampValue(newZoom !== null && newZoom !== void 0 ? newZoom : 1, _this._rootStore.diagramSettings.zoomInterval);
            }
        });
        Object.defineProperty(this, "reportWhenImportedStateRendered", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                _this._renderImportedRequestId++;
            }
        });
        Object.defineProperty(this, "zoomIn", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () { return _this.zoomIntoCenter(1 / 0.8); }
        });
        Object.defineProperty(this, "zoomOut", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () { return _this.zoomIntoCenter(0.8); }
        });
        // See: https://stackoverflow.com/a/30039971/9142642
        Object.defineProperty(this, "zoomInto", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (pointToZoomInto, zoomMultiplicator) {
                var newZoom = clampValue(_this._zoom * zoomMultiplicator, _this._rootStore.diagramSettings.zoomInterval);
                var pointDisplacementAfterZoom = multiplyPoint(subtractPoints(pointToZoomInto, _this._offset), newZoom / _this._zoom);
                _this.setTransformation(
                // Compensate for the displacement by moving the point back under the cursor
                subtractPoints(pointToZoomInto, pointDisplacementAfterZoom), newZoom);
            }
        });
        Object.defineProperty(this, "setTransformation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newOffset, newZoom) {
                _this.setOffset(newOffset);
                _this.setZoom(newZoom);
            }
        });
        Object.defineProperty(this, "translate", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (translateBy) {
                _this.setOffset(addPoints(_this._offset, translateBy));
            }
        });
        Object.defineProperty(this, "translateAndZoomInto", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (translateBy, pointToZoomInto, zoomMultiplicator) {
                _this.translate(translateBy);
                _this.zoomInto(pointToZoomInto, zoomMultiplicator);
            }
        });
        Object.defineProperty(this, "zoomIntoCenter", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (zoomMultiplicator) {
                if (_this.ref.boundingRect) {
                    _this.zoomInto(multiplyPoint(_this.ref.boundingRect.size, 0.5), zoomMultiplicator);
                }
            }
        });
        /**
         * Get position on Diagram in its coordinates system (including zoom) by mouse/touch position.
         * @param pointerPosition position of mouse or finger on the screen
         */
        Object.defineProperty(this, "getPositionByPointer", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (pointerPosition) {
                var _a;
                var diagRect = (_a = _this.ref.current) === null || _a === void 0 ? void 0 : _a.getBoundingClientRect();
                if (diagRect) {
                    return multiplyPoint(subtractPoints(pointerPosition, [diagRect.left, diagRect.top], _this.offset), 1 / _this.zoom);
                }
                else
                    return [0, 0];
            }
        });
        Object.defineProperty(this, "zoomToFit", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                var _a;
                var nodesBoundingBox = _this._getNodesBoundingBoxWithPadding();
                var diagramSize = (_a = _this.ref.boundingRect) === null || _a === void 0 ? void 0 : _a.size;
                if (!diagramSize) {
                    console.warn('Cannot retrieve diagram size');
                    return;
                }
                var newZoom = clampValue(calculateNewZoomToFitBoundingBox(diagramSize, nodesBoundingBox), _this._rootStore.diagramSettings.zoomToFitSettings.zoomInterval);
                _this.setZoom(newZoom);
                _this.setOffset(calculateOffsetToCenterBoundingBox(diagramSize, newZoom, nodesBoundingBox));
            }
        });
        Object.defineProperty(this, "_getNodesBoundingBoxWithPadding", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                var nodesBoundingBox = _this._rootStore.nodesStore.getNodesBoundingBox();
                var padding = _this._rootStore.diagramSettings.zoomToFitSettings.padding;
                nodesBoundingBox.topLeftCorner = subtractPoints(nodesBoundingBox.topLeftCorner, padding);
                nodesBoundingBox.bottomRightCorner = addPoints(nodesBoundingBox.bottomRightCorner, padding);
                nodesBoundingBox.size = subtractPoints(nodesBoundingBox.bottomRightCorner, nodesBoundingBox.topLeftCorner);
                return nodesBoundingBox;
            }
        });
        this._ref = new HtmlElementRefState(null, this);
        this._rootStore = rootStore;
        this.import();
        mobx.makeAutoObservable(this, {
            _rootStore: false,
        });
    }
    Object.defineProperty(DiagramState.prototype, "renderImportedRequestId", {
        get: function () {
            return this._renderImportedRequestId;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramState.prototype, "ref", {
        get: function () {
            return this._ref;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramState.prototype, "offset", {
        get: function () {
            return this._offset;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramState.prototype, "zoom", {
        get: function () {
            return this._zoom;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DiagramState.prototype, "getRenderedZoom", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            var attr = this.ref.getDataAttribute('data-zoom');
            return attr ? Number(attr) : null;
        }
    });
    return DiagramState;
}());
function calculateNewZoomToFitBoundingBox(diagramSize, boundingBox) {
    // Zoom to fit the largest size, horizontal or vertical
    var newZoom = Math.min(diagramSize[0] / boundingBox.size[0], diagramSize[1] / boundingBox.size[1]);
    return newZoom;
}
function calculateOffsetToCenterBoundingBox(diagramSize, zoom, boundingBox) {
    // Take zoom into account
    var contentSizeWithZoom = multiplyPoint(boundingBox.size, zoom);
    var topLeftCornerWithZoom = multiplyPoint(boundingBox.topLeftCorner, zoom);
    var diffBetweenDiagramAndContentSizes = subtractPoints(diagramSize, contentSizeWithZoom);
    return addPoints(multiplyPoint(topLeftCornerWithZoom, -1), // topLeft corner of content will be at topleft corner of diagram
    multiplyPoint(diffBetweenDiagramAndContentSizes, 1 / 2) // center content
    );
}

function useStyling(options, state) {
    return React.useMemo(function () {
        return {
            className: generateClassName(options, state),
            style: generateStyle(options, state),
        };
    }, [options, state]);
}
function generateClassName(options, state) {
    var defaultStateDefaultClasses = !options.removeDefaultClasses && options.baseState !== state
        ? getValueForState(options.baseState, options.defaultClasses, options)
        : undefined;
    var defaultClasses = !options.removeDefaultClasses
        ? getValueForState(state, options.defaultClasses, options)
        : undefined;
    var defaultStateClasses = options.baseState !== state
        ? getValueForState(options.baseState, options.classes, options)
        : undefined;
    var classes = getValueForState(state, options.classes, options);
    return combineArrays(defaultStateDefaultClasses, defaultClasses, defaultStateClasses, classes).join(' ');
}
function generateStyle(options, state) {
    var defaultStateDefaultStyles = options.baseState !== state
        ? getValueForState(options.baseState, options.defaultStyle, options)
        : undefined;
    var defaultStyles = getValueForState(state, options.defaultStyle, options);
    var defaultStateStyles = options.baseState !== state
        ? getValueForState(options.baseState, options.style, options)
        : undefined;
    var styles = getValueForState(state, options.style, options);
    return __assign(__assign(__assign(__assign({}, defaultStateDefaultStyles), defaultStyles), defaultStateStyles), styles);
}
function getValueForState(state, dict, options) {
    var _a;
    if (dict && state) {
        var val = dict[state];
        if (!val && ((_a = options.spareStates) === null || _a === void 0 ? void 0 : _a[state])) {
            var spareStates = options.spareStates[state];
            for (var i = 0; i < spareStates.length; i++) {
                var spareState = spareStates[i];
                val = dict[spareState];
                if (val)
                    break;
            }
        }
        return val;
    }
    else
        return undefined;
}

var LinkDefault = mobxReactLite.observer(function (_a) {
    var entity = _a.entity, settings = _a.settings, bind = _a.bind;
    var mainStylingOptions = React.useMemo(function () {
        var _a, _b;
        return ({
            removeDefaultClasses: settings === null || settings === void 0 ? void 0 : settings.removeDefaultClasses,
            baseState: 'base',
            classes: (_a = settings === null || settings === void 0 ? void 0 : settings.mainLine) === null || _a === void 0 ? void 0 : _a.classes,
            defaultClasses: defaultLinkMainLineClasses,
            style: (_b = settings === null || settings === void 0 ? void 0 : settings.mainLine) === null || _b === void 0 ? void 0 : _b.style,
            spareStates: { 'selected-hovered': ['selected', 'hovered'] }
        });
    }, [settings]);
    var secondaryStylingOptions = React.useMemo(function () {
        var _a, _b;
        return ({
            removeDefaultClasses: settings === null || settings === void 0 ? void 0 : settings.removeDefaultClasses,
            baseState: 'base',
            classes: (_a = settings === null || settings === void 0 ? void 0 : settings.secondaryLine) === null || _a === void 0 ? void 0 : _a.classes,
            defaultClasses: defaultLinkSecondaryLineClasses,
            style: (_b = settings === null || settings === void 0 ? void 0 : settings.secondaryLine) === null || _b === void 0 ? void 0 : _b.style,
            spareStates: { 'selected-hovered': ['selected', 'hovered'] }
        });
    }, [settings]);
    var state = 'base';
    if (entity.selected && entity.hovered)
        state = 'selected-hovered';
    else if (entity.selected)
        state = 'selected';
    else if (entity.hovered)
        state = 'hovered';
    var mainStyling = useStyling(mainStylingOptions, state);
    var secondaryStyling = useStyling(secondaryStylingOptions, state);
    if (!entity.path)
        return null;
    return (React__default["default"].createElement("g", null,
        React__default["default"].createElement("path", { d: entity.path.svgPath, className: mainStyling.className, style: mainStyling.style }),
        React__default["default"].createElement("path", __assign({ d: entity.path.svgPath, className: secondaryStyling.className, style: secondaryStyling.style }, bind()))));
});
var defaultLinkMainLineClasses = {
    base: ['react_fast_diagram_LinkDefault_Line'],
    hovered: ['react_fast_diagram_LinkDefault_Line_Hovered'],
    selected: ['react_fast_diagram_LinkDefault_Line_Selected'],
};
var defaultLinkSecondaryLineClasses = {
    base: [
        'react_fast_diagram_LinkDefault_Line',
        'react_fast_diagram_LinkDefault_SecondaryLine',
    ],
    hovered: [
        'react_fast_diagram_LinkDefault_Line_Hovered',
        'react_fast_diagram_LinkDefault_SecondaryLine_Hovered',
    ],
    'selected-hovered': [
        'react_fast_diagram_LinkDefault_Line_Selected',
        'react_fast_diagram_LinkDefault_SecondaryLine_Hovered',
    ],
};
function createLinkDefault(settings) {
    return {
        component: LinkDefault,
        settings: settings,
    };
}

function getDegree(dir) {
    switch (dir) {
        case 'left':
            return 180;
        case 'up':
            return 90;
        case 'right':
            return 0;
        case 'down':
            return 270;
        case 'left-up':
            return 135;
        case 'right-up':
            return 45;
        case 'right-down':
            return 315;
        case 'left-down':
            return 225;
        default:
            return undefined;
    }
}
function getRadian(dir) {
    var degree = getDegree(dir);
    return degree !== undefined ? (degree * Math.PI) / 180 : undefined;
}
function createVector(p, length, angleInRadian) {
    return [
        p[0] + length * (angleInRadian !== undefined ? Math.cos(angleInRadian) : 0),
        p[1] +
            length * (angleInRadian !== undefined ? -Math.sin(angleInRadian) : 0),
    ];
}
function commandM(point) {
    return 'M ' + coordinateFromPoint(point);
}
function commandC(startPoint, control1, control2, endPoint) {
    return (commandM(startPoint) +
        ' C ' +
        coordinateFromPoint(control1) +
        ' ' +
        coordinateFromPoint(control2) +
        ' ' +
        coordinateFromPoint(endPoint));
}
function coordinateFromPoint(point) {
    return point[0] + " " + point[1];
}

function curvedLinkPathConstructor(source, target, settings) {
    if (!source || !target)
        return '';
    var directionFactor = settings.tweakDirectionFactorBasedOnDistance(distanceBetweenPoints(source.point, target.point), settings.directionFactor);
    return commandC(source.point, createVector(source.point, directionFactor, getRadian(source.direction)), createVector(target.point, directionFactor, getRadian(target.direction)), target.point);
}
var defaultSettings = {
    directionFactor: 60,
    tweakDirectionFactorBasedOnDistance: function (distance, directionFactor) {
        if (distance < 100) {
            return directionFactor * (distance / 100);
        }
        return directionFactor;
    },
};
function createCurvedLinkPathConstructor(settings) {
    return function (source, target) {
        return curvedLinkPathConstructor(source, target, settings ? __assign(__assign({}, defaultSettings), settings) : defaultSettings);
    };
}

var LinkPointEndpointState = /** @class */ (function () {
    function LinkPointEndpointState(pos) {
        var _this = this;
        Object.defineProperty(this, "_point", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "translateBy", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (pointToTranslateBy) {
                _this._point = addPoints(_this._point, pointToTranslateBy);
            }
        });
        this._point = pos;
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(LinkPointEndpointState.prototype, "point", {
        get: function () {
            return this._point;
        },
        enumerable: false,
        configurable: true
    });
    return LinkPointEndpointState;
}());

var LinkPortEndpointState = /** @class */ (function () {
    function LinkPortEndpointState(port, rootStore) {
        var _this = this;
        Object.defineProperty(this, "_port", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                return deepCopy({
                    nodeId: _this._port.nodeId,
                    portId: _this._port.id,
                });
            }
        });
        this._port = port;
        mobx.makeAutoObservable(this);
        this._rootStore = rootStore;
    }
    Object.defineProperty(LinkPortEndpointState.prototype, "port", {
        get: function () {
            return this._port;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkPortEndpointState.prototype, "point", {
        get: function () {
            if (this.port.offsetRelativeToNode && this.port.ref.sizeExcludingZoom) {
                return addPoints(this.port.node.position, addPoints(this.port.offsetRelativeToNode, multiplyPoint(this.port.ref.sizeExcludingZoom, 0.5)));
            }
            return undefined;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkPortEndpointState.prototype, "portId", {
        get: function () {
            return this.port.id;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkPortEndpointState.prototype, "nodeId", {
        get: function () {
            return this.port.node.id;
        },
        enumerable: false,
        configurable: true
    });
    return LinkPortEndpointState;
}());
function linkPortEndpointsEquals(a, b) {
    return a.nodeId === b.nodeId && a.portId === b.portId;
}

var VisualComponents = /** @class */ (function () {
    function VisualComponents(defaultComponents) {
        var _this = this;
        Object.defineProperty(this, "_defaultComponents", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_components", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (obj) {
                _this._components = __assign(__assign({}, _this._defaultComponents), _this._createComponentCollection(obj === null || obj === void 0 ? void 0 : obj.components));
            }
        });
        Object.defineProperty(this, "getComponent", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (type) {
                var _a;
                var finalComponentType = type !== null && type !== void 0 ? type : COMPONENT_DEFAULT_TYPE;
                return ((_a = _this._components[finalComponentType]) !== null && _a !== void 0 ? _a : _this._components[COMPONENT_DEFAULT_TYPE]);
            }
        });
        Object.defineProperty(this, "_createComponentCollection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (componentsObjects) {
                var collection = {};
                componentsObjects &&
                    Object.entries(componentsObjects).forEach(function (_a) {
                        var key = _a[0], value = _a[1];
                        collection[key] = new VisualComponentState(value);
                    });
                return collection;
            }
        });
        this._defaultComponents = this._createComponentCollection(defaultComponents);
        this._components = __assign({}, this._defaultComponents);
        mobx.makeAutoObservable(this);
    }
    return VisualComponents;
}());
var COMPONENT_DEFAULT_TYPE = 'default';

var LinkState = /** @class */ (function () {
    function LinkState(rootStore, id, state) {
        var _this = this;
        Object.defineProperty(this, "_id", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_type", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_source", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_sourceEndpoint", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_target", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_targetEndpoint", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_segments", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_selected", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_hovered", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_isSelectionEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (state) {
                _this._sourceEndpoint = {
                    nodeId: state.source.nodeId,
                    portId: state.source.portId,
                };
                _this._targetEndpoint = {
                    nodeId: state.target.nodeId,
                    portId: state.target.portId,
                };
                _this.setType(state.type);
                _this.setSegments(state.segments);
                _this.setData(state.data);
                _this.setIsSelectionEnabled(state === null || state === void 0 ? void 0 : state.isSelectionEnabled);
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                var _a;
                return (__assign({}, deepCopy({
                    id: _this._id,
                    source: _this._sourceEndpoint,
                    target: _this._targetEndpoint,
                    type: _this.type,
                    segments: _this.segments,
                    data: _this.data,
                    isSelectionEnabled: (_a = _this._isSelectionEnabled) !== null && _a !== void 0 ? _a : undefined,
                })));
            }
        });
        Object.defineProperty(this, "setType", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._type = value !== null && value !== void 0 ? value : COMPONENT_DEFAULT_TYPE;
            }
        });
        Object.defineProperty(this, "setSegments", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._segments = value !== null && value !== void 0 ? value : [];
            }
        });
        Object.defineProperty(this, "swapEndpoints", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                var tmp = _this.sourceEndpoint;
                _this._sourceEndpoint = _this.targetEndpoint;
                _this._targetEndpoint = tmp;
            }
        });
        Object.defineProperty(this, "setData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._data = value !== null && value !== void 0 ? value : null;
            }
        });
        Object.defineProperty(this, "setIsSelectionEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._isSelectionEnabled = isBoolean(value) ? value : null;
            }
        });
        Object.defineProperty(this, "_createEndpointState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (endpoint) {
                var node = _this._rootStore.nodesStore.getNode(endpoint.nodeId);
                if (!node)
                    return undefined;
                var port = node.getPort(endpoint.portId);
                if (!port)
                    return undefined;
                return new LinkPortEndpointState(port, _this._rootStore);
            }
        });
        this._rootStore = rootStore;
        this._id = id;
        this._selected = false;
        this._hovered = false;
        this.import(state);
        mobx.makeAutoObservable(this, {
            // @ts-ignore
            _rootStore: false
        });
    }
    Object.defineProperty(LinkState.prototype, "id", {
        get: function () {
            return this._id;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "type", {
        get: function () {
            return this._type;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "segments", {
        get: function () {
            return this._segments;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "path", {
        get: function () {
            if (this.source && this.target) {
                return createLinkPath(this._rootStore, this.source, this.target);
            }
            return undefined;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "componentDefinition", {
        get: function () {
            var visualComponents = this._rootStore.linksSettings.visualComponents;
            return visualComponents.getComponent(this.type);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "selected", {
        get: function () {
            return this._selected;
        },
        set: function (value) {
            this._selected = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "hovered", {
        get: function () {
            return this._hovered;
        },
        set: function (value) {
            this._hovered = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "data", {
        get: function () {
            return this._data;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "source", {
        get: function () {
            return this._createEndpointState(this.sourceEndpoint);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "sourceEndpoint", {
        get: function () {
            return this._sourceEndpoint;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "target", {
        get: function () {
            return this._createEndpointState(this.targetEndpoint);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "targetEndpoint", {
        get: function () {
            return this._targetEndpoint;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkState.prototype, "isSelectionEnabled", {
        get: function () {
            return this._isSelectionEnabled === null
                ? this._rootStore.diagramSettings.userInteraction.linkSelection
                : this._isSelectionEnabled;
        },
        enumerable: false,
        configurable: true
    });
    return LinkState;
}());
function createLinkPath(rootStore, source, target) {
    var linksSettings = rootStore.linksSettings;
    if (!source.port ||
        (target instanceof LinkPortEndpointState && !target.port) ||
        !source.point ||
        !target.point) {
        return undefined;
    }
    var pathStr = linksSettings.pathConstructor({
        point: source.point,
        portType: source.port.type,
        direction: source.port.linkDirection,
    }, {
        point: target.point,
        portType: target instanceof LinkPointEndpointState
            ? undefined
            : target.port.type,
        direction: target instanceof LinkPointEndpointState
            ? undefined
            : target.port.linkDirection,
    });
    return {
        svgPath: pathStr,
        source: source.point,
        target: target.point,
    };
}

var LinkCreationState = /** @class */ (function () {
    function LinkCreationState(rootStore) {
        var _this = this;
        Object.defineProperty(this, "_source", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: undefined
        });
        Object.defineProperty(this, "_target", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: undefined
        });
        Object.defineProperty(this, "_targetPortCandidate", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: undefined
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "startLinking", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (portState, pointOnPort) {
                _this._resetProps();
                _this._source = new LinkPortEndpointState(portState, _this._rootStore);
                var sourcePoint = _this._source.point;
                var portSize = _this._source.port.ref.sizeExcludingZoom;
                if (sourcePoint && portSize) {
                    // endpoint point is calculated for center of port
                    var topLeftCornerPoint = subtractPoints(sourcePoint, multiplyPoint(portSize, 0.5));
                    _this._target = new LinkPointEndpointState(addPoints(topLeftCornerPoint, multiplyPoint(pointOnPort, 1 / _this._rootStore.diagramState.zoom)));
                }
                else {
                    _this._resetProps();
                    return false;
                }
                _this._rootStore.callbacks.linkingStarted({
                    sourcePort: portState,
                });
                return true;
            }
        });
        Object.defineProperty(this, "setTargetPortCandidate", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (portState) {
                if (!_this._source)
                    return;
                var canAddLink = _this._rootStore.linksStore.validateLink({
                    source: {
                        nodeId: _this._source.port.nodeId,
                        portId: _this._source.port.id,
                    },
                    target: {
                        nodeId: portState.nodeId,
                        portId: portState.id,
                    },
                });
                _this._targetPortCandidate = portState;
                if (canAddLink.success) {
                    portState.validForConnection = true;
                }
                else {
                    portState.validForConnection = false;
                }
            }
        });
        Object.defineProperty(this, "resetTargetPortCandidate", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (portState) {
                if (_this._targetPortCandidate === portState) {
                    _this._targetPortCandidate = undefined;
                }
                portState.validForConnection = true;
            }
        });
        Object.defineProperty(this, "stopLinking", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                var linked = false;
                if (_this._targetPortCandidate && _this._source) {
                    var result = _this._rootStore.linksStore.addLink({
                        source: {
                            nodeId: _this._source.port.nodeId,
                            portId: _this._source.port.id,
                        },
                        target: {
                            nodeId: _this._targetPortCandidate.nodeId,
                            portId: _this._targetPortCandidate.id,
                        },
                    });
                    if (result.success) {
                        _this._rootStore.selectionState.select(result.value, true);
                    }
                    linked = result.success;
                }
                if (_this._source) {
                    _this._rootStore.callbacks.linkingEnded({
                        sourcePort: _this._source.port,
                        targetPort: _this._targetPortCandidate,
                        linked: linked,
                    });
                }
                _this._resetProps();
            }
        });
        Object.defineProperty(this, "_resetProps", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                if (_this._source) {
                    if (_this._source.port) {
                        _this._source.port.validForConnection = true;
                    }
                    _this._source = undefined;
                }
                _this._target = undefined;
                if (_this._targetPortCandidate) {
                    _this._targetPortCandidate.validForConnection = true;
                    _this._targetPortCandidate = undefined;
                }
            }
        });
        mobx.makeAutoObservable(this);
        this._rootStore = rootStore;
    }
    Object.defineProperty(LinkCreationState.prototype, "selected", {
        get: function () {
            return true;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkCreationState.prototype, "hovered", {
        get: function () {
            return true;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkCreationState.prototype, "source", {
        get: function () {
            return this._source;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkCreationState.prototype, "target", {
        get: function () {
            return this._target;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkCreationState.prototype, "targetPortCandidate", {
        get: function () {
            return this._targetPortCandidate;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkCreationState.prototype, "isLinking", {
        get: function () {
            return !!this._source;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkCreationState.prototype, "componentDefinition", {
        get: function () {
            var visualComponents = this._rootStore.linksSettings.visualComponents;
            return visualComponents.getComponent(LINK_CREATION_COMPONENT_TYPE);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinkCreationState.prototype, "path", {
        get: function () {
            if (!this._source || !this._target)
                return undefined;
            else
                return createLinkPath(this._rootStore, this._source, this._target);
        },
        enumerable: false,
        configurable: true
    });
    return LinkCreationState;
}());
var LINK_CREATION_COMPONENT_TYPE = 'linkCreation';

var CircleMarker = React__default["default"].memo(function (props) {
    var _a;
    var finalSettings = {
        id: props.id,
        radius: (_a = props.radius) !== null && _a !== void 0 ? _a : 2,
        style: __assign({ stroke: 'none', fill: 'rgb(194, 194, 194)' }, props.style),
    };
    return (React__default["default"].createElement("marker", { id: finalSettings.id, overflow: 'visible', markerUnits: 'userSpaceOnUse' },
        React__default["default"].createElement("circle", { r: finalSettings.radius, style: finalSettings.style })));
});
function createCircleMarker(settings) {
    return function () { return React__default["default"].createElement(CircleMarker, __assign({}, settings)); };
}
var ArrowMarker = React__default["default"].memo(function (props) {
    var _a, _b;
    var finalSettings = {
        id: props.id,
        height: (_a = props.height) !== null && _a !== void 0 ? _a : 10,
        width: (_b = props.width) !== null && _b !== void 0 ? _b : 10,
        style: __assign({ stroke: 'none', fill: 'rgb(194, 194, 194)' }, props.style),
    };
    return (React__default["default"].createElement("marker", { id: finalSettings.id, overflow: 'visible', markerUnits: 'userSpaceOnUse', refX: '-0.5', orient: 'auto' },
        React__default["default"].createElement("path", { d: "M 0 0 -" + finalSettings.width + " -" + finalSettings.height / 2 + " -" + finalSettings.width + " " + finalSettings.height / 2 + " z", style: finalSettings.style })));
});
function createArrowMarker(settings) {
    return function () { return React__default["default"].createElement(ArrowMarker, __assign({}, settings)); };
}

var LinksSettings = /** @class */ (function () {
    function LinksSettings() {
        var _a;
        var _this = this;
        Object.defineProperty(this, "_pathConstructor", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_visualComponents", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new VisualComponents((_a = {},
                _a[COMPONENT_DEFAULT_TYPE] = createLinkDefault(),
                _a[LINK_CREATION_COMPONENT_TYPE] = createLinkDefault({
                    mainLine: {
                        style: {
                            base: { markerEnd: 'url(#default_circle_marker_hovered)' },
                        },
                    },
                }),
                _a))
        });
        Object.defineProperty(this, "_preferLinksDirection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_defaultSvgMarkers", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: [
                createCircleMarker({
                    id: 'default_circle_marker',
                    style: {
                        fill: '#c2c2c2',
                    },
                }),
                createCircleMarker({
                    id: 'default_circle_marker_selected',
                    style: {
                        fill: '#6eb7ff',
                    },
                }),
                createCircleMarker({
                    id: 'default_circle_marker_hovered',
                    style: {
                        fill: '#a1d0ff',
                    },
                }),
                createArrowMarker({
                    id: 'default_arrow_marker',
                    style: {
                        fill: '#c2c2c2',
                    },
                }),
                createArrowMarker({
                    id: 'default_arrow_marker_selected',
                    style: {
                        fill: '#6eb7ff',
                    },
                }),
                createArrowMarker({
                    id: 'default_arrow_marker_hovered',
                    style: {
                        fill: '#a1d0ff',
                    },
                }),
            ]
        });
        Object.defineProperty(this, "_svgMarkers", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: []
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (obj) {
                var _a;
                _this._visualComponents.import(obj);
                _this.setPathConstructor(obj === null || obj === void 0 ? void 0 : obj.pathConstructor);
                _this._preferLinksDirection = (_a = obj === null || obj === void 0 ? void 0 : obj.preferLinksDirection) !== null && _a !== void 0 ? _a : 'horizontal';
                _this._svgMarkers = (obj === null || obj === void 0 ? void 0 : obj.svgMarkers) ? __spreadArrays(obj.svgMarkers, _this._defaultSvgMarkers) : _this._defaultSvgMarkers;
            }
        });
        Object.defineProperty(this, "setPathConstructor", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._pathConstructor = value !== null && value !== void 0 ? value : defaultPathConstructor;
            }
        });
        this.import();
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(LinksSettings.prototype, "pathConstructor", {
        get: function () {
            return this._pathConstructor;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinksSettings.prototype, "visualComponents", {
        get: function () {
            return this._visualComponents;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinksSettings.prototype, "preferLinksDirection", {
        get: function () {
            return this._preferLinksDirection;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinksSettings.prototype, "svgMarkers", {
        get: function () {
            return this._svgMarkers;
        },
        enumerable: false,
        configurable: true
    });
    return LinksSettings;
}());
var defaultPathConstructor = createCurvedLinkPathConstructor();

var PortState = /** @class */ (function () {
    function PortState(rootStore, node, id, state) {
        var _this = this;
        Object.defineProperty(this, "_id", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_label", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_type", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_linkDirection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_isConnectionEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_position", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_offsetFromNodeCenter", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_offsetFromOrigin", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_ref", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_dragging", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: false
        });
        Object.defineProperty(this, "_hovered", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: false
        });
        Object.defineProperty(this, "_validForConnection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: true
        });
        Object.defineProperty(this, "_offsetRecalculationRequested", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: 0
        });
        Object.defineProperty(this, "_triggerOffsetRecalculation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: 0
        });
        Object.defineProperty(this, "_node", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "setLabel", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._label = value;
            }
        });
        Object.defineProperty(this, "setType", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._type = value;
            }
        });
        Object.defineProperty(this, "setPosition", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._position = value;
            }
        });
        Object.defineProperty(this, "setOffsetFromNodeCenter", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._offsetFromNodeCenter = value;
            }
        });
        Object.defineProperty(this, "setOffsetFromOrigin", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._offsetFromOrigin = value;
            }
        });
        /**
         * Update all properties. If some property missing in `state` parameter, the default one will be used.
         */
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (state) {
                _this.setType(state === null || state === void 0 ? void 0 : state.type);
                _this.setLabel(state === null || state === void 0 ? void 0 : state.label);
                _this.setData(state === null || state === void 0 ? void 0 : state.data);
                _this.setLinkDirection(state === null || state === void 0 ? void 0 : state.linkDirection);
                _this.setIsConnectionEnabled(state === null || state === void 0 ? void 0 : state.isConnectionEnabled);
                _this.setPosition(state === null || state === void 0 ? void 0 : state.position);
                _this.setOffsetFromNodeCenter(state === null || state === void 0 ? void 0 : state.offsetFromNodeCenter);
                _this.setOffsetFromOrigin(state === null || state === void 0 ? void 0 : state.offsetFromOrigin);
            }
        });
        /**
         * Update only those properties presented in `state` parameter
         */
        Object.defineProperty(this, "update", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (state) {
                if (!state)
                    return;
                state.label !== undefined && _this.setLabel(state.label);
                state.type !== undefined && _this.setType(state.type);
                state.data !== undefined && _this.setData(state.data);
                state.linkDirection !== undefined &&
                    _this.setLinkDirection(state.linkDirection);
                state.isConnectionEnabled !== undefined &&
                    _this.setIsConnectionEnabled(state.isConnectionEnabled);
                state.position !== undefined && _this.setPosition(state === null || state === void 0 ? void 0 : state.position);
                state.offsetFromNodeCenter !== undefined &&
                    _this.setOffsetFromNodeCenter(state === null || state === void 0 ? void 0 : state.offsetFromNodeCenter);
                state.offsetFromOrigin !== undefined &&
                    _this.setOffsetFromOrigin(state === null || state === void 0 ? void 0 : state.offsetFromOrigin);
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                return deepCopy({
                    id: _this._id,
                    nodeId: _this.nodeId,
                    label: _this._label,
                    type: _this._type,
                    data: _this._data,
                    linkDirection: _this._linkDirection,
                    isConnectionEnabled: _this._isConnectionEnabled,
                    position: _this._position,
                    offsetFromNodeCenter: _this._offsetFromNodeCenter,
                    offsetFromOrigin: _this._offsetFromOrigin,
                });
            }
        });
        Object.defineProperty(this, "setData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._data = value;
            }
        });
        Object.defineProperty(this, "recalculateOffset", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                _this._offsetRecalculationRequested += 1;
            }
        });
        Object.defineProperty(this, "recalculateOffsetImmediately", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                _this._triggerOffsetRecalculation += 1;
            }
        });
        Object.defineProperty(this, "setLinkDirection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._linkDirection = value;
            }
        });
        Object.defineProperty(this, "setIsConnectionEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                _this._isConnectionEnabled = value;
            }
        });
        this._id = id;
        this._node = node;
        this._rootStore = rootStore;
        this._ref = new HtmlElementRefState(null, rootStore.diagramState);
        this.import(state);
        mobx.makeAutoObservable(this, {
            _node: false,
            node: false,
            _rootStore: false,
            _ref: false,
        });
        mobx.reaction(function () { return [
            _this._label,
            _this._type,
            _this._data,
            _this._position,
            _this._offsetFromNodeCenter,
            _this._offsetFromOrigin,
        ]; }, function () {
            _this.recalculateOffset();
        });
    }
    Object.defineProperty(PortState.prototype, "nodeComponentPortState", {
        get: function () {
            var _this = this;
            var _a, _b;
            return (_b = (_a = this.node.componentDefinition.settings) === null || _a === void 0 ? void 0 : _a.ports) === null || _b === void 0 ? void 0 : _b.find(function (p) { return p.id === _this._id; });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "id", {
        get: function () {
            return this._id;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "nodeId", {
        get: function () {
            return this.node.id;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "fullId", {
        get: function () {
            return createFullPortId(this.nodeId, this.id);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "ref", {
        get: function () {
            return this._ref;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "dragging", {
        get: function () {
            return this._dragging;
        },
        set: function (value) {
            this._dragging = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "hovered", {
        get: function () {
            return this._hovered;
        },
        set: function (value) {
            this._hovered = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "validForConnection", {
        get: function () {
            return this._validForConnection;
        },
        set: function (value) {
            this._validForConnection = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "label", {
        get: function () {
            var _a, _b;
            return this._label === undefined
                ? (_a = this.nodeComponentPortState) === null || _a === void 0 ? void 0 : _a.label : (_b = this._label) !== null && _b !== void 0 ? _b : undefined;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "type", {
        get: function () {
            var _a, _b;
            return ((_b = (this._type === undefined
                ? (_a = this.nodeComponentPortState) === null || _a === void 0 ? void 0 : _a.type : this._type)) !== null && _b !== void 0 ? _b : COMPONENT_DEFAULT_TYPE);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "position", {
        get: function () {
            var _a, _b;
            return this._position === undefined
                ? (_a = this.nodeComponentPortState) === null || _a === void 0 ? void 0 : _a.position : (_b = this._position) !== null && _b !== void 0 ? _b : undefined;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "offsetFromNodeCenter", {
        get: function () {
            var _a, _b;
            return this._offsetFromNodeCenter === undefined
                ? (_a = this.nodeComponentPortState) === null || _a === void 0 ? void 0 : _a.offsetFromNodeCenter : (_b = this._offsetFromNodeCenter) !== null && _b !== void 0 ? _b : undefined;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "offsetFromOrigin", {
        get: function () {
            var _a, _b;
            return this._offsetFromOrigin === undefined
                ? (_a = this.nodeComponentPortState) === null || _a === void 0 ? void 0 : _a.offsetFromOrigin : (_b = this._offsetFromOrigin) !== null && _b !== void 0 ? _b : undefined;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "data", {
        get: function () {
            var _a;
            return this._data === undefined
                ? (_a = this.nodeComponentPortState) === null || _a === void 0 ? void 0 : _a.data : this._data;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "node", {
        get: function () {
            return this._node;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "offsetRelativeToNode", {
        /**
         * Offset relative to parent node, helps us to calculate positions of link endpoints for example.
         * @returns offset excluding zoom
         */
        get: function () {
            /* This value is implemented as getter to automatically recalculate
            value if html element is attached (react ref) and also it helps with performance
            as if there is no observers the value will not be calculated */
            this._triggerOffsetRecalculation | 1;
            /* There is another method of calculating offset by using getBoundingClientReact, but it
            has its drawbacks like that it return position related to viewport and therefore requires
            from us to synchronize moments when node and port getBoundingClientReact is called. It also
            requires using diagram zoom to correctly calculate offset. */
            if (this.ref.current && this.node.ref.current) {
                var iterElement = this.ref.current;
                var nextOffsetParent = null;
                var acumLeft = 0;
                var acumTop = 0;
                while (this.node.ref.current !== iterElement && iterElement) {
                    if (!nextOffsetParent || nextOffsetParent === iterElement) {
                        var translate = getTranslate(iterElement);
                        acumLeft += iterElement.offsetLeft + translate[0];
                        acumTop += iterElement.offsetTop + translate[1];
                        nextOffsetParent = iterElement.offsetParent;
                    }
                    iterElement = iterElement.parentElement;
                }
                return [acumLeft, acumTop];
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "offsetRecalculationRequested", {
        /**
         * Is used to trigger port rerendering and following offset recalculation
         */
        get: function () {
            return this._offsetRecalculationRequested;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "componentDefinition", {
        get: function () {
            var portVisualComponents = this._rootStore.portsSettings.portVisualComponents;
            return portVisualComponents.getComponent(this.type);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "connectedLinks", {
        get: function () {
            return this._rootStore.linksStore.getPortLinks(this.nodeId, this.id);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "connectedPorts", {
        get: function () {
            var _this = this;
            return this.connectedLinks
                .map(function (v) { var _a, _b; return v.sourceEndpoint.portId === _this._id ? (_a = v.target) === null || _a === void 0 ? void 0 : _a.port : (_b = v.source) === null || _b === void 0 ? void 0 : _b.port; })
                .filter(function (p) { return p; }); // cast because typescript cannot deal with undefined check
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "linkDirection", {
        get: function () {
            if (this._linkDirection)
                return this._linkDirection;
            if (this.position)
                return positionToLinkDirection[this.position];
            // Try to guess
            if (!this.offsetRelativeToNode)
                return undefined;
            var nodeCenter = this.node.ref.sizeExcludingZoom &&
                multiplyPoint(this.node.ref.sizeExcludingZoom, 0.5);
            if (!nodeCenter)
                return undefined;
            if (this._rootStore.linksSettings.preferLinksDirection === 'horizontal') {
                return this.offsetRelativeToNode[0] < nodeCenter[0] ? 'left' : 'right';
            }
            else if (this._rootStore.linksSettings.preferLinksDirection === 'vertical') {
                return this.offsetRelativeToNode[1] < nodeCenter[1] ? 'up' : 'down';
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PortState.prototype, "isConnectionEnabled", {
        get: function () {
            var _a, _b;
            return ((_b = (this._isConnectionEnabled === undefined
                ? (_a = this.nodeComponentPortState) === null || _a === void 0 ? void 0 : _a.isConnectionEnabled : this._isConnectionEnabled)) !== null && _b !== void 0 ? _b : this._rootStore.diagramSettings.userInteraction.portConnection);
        },
        enumerable: false,
        configurable: true
    });
    return PortState;
}());
var positionToLinkDirection = {
    'left-center': 'left',
    'left-bottom': 'left',
    'left-top': 'left',
    'top-left': 'up',
    'top-center': 'up',
    'top-right': 'up',
    'right-center': 'right',
    'right-bottom': 'right',
    'right-top': 'right',
    'bottom-left': 'down',
    'bottom-center': 'down',
    'bottom-right': 'down',
    'diagonal-left-top': 'left-up',
    'diagonal-right-top': 'right-up',
    'diagonal-right-bottom': 'right-down',
    'diagonal-left-bottom': 'left-down',
};
// https://stackoverflow.com/questions/21912684/how-to-get-value-of-translatex-and-translatey
// https://gist.github.com/aderaaij/a6b666bf756b2db1596b366da921755d
function getTranslate(item) {
    var transArr = [0, 0];
    if (!window.getComputedStyle) {
        return transArr;
    }
    var style = window.getComputedStyle(item);
    var transform = style.transform || style.webkitTransform;
    // matrix(a, b, c, d, tx, ty)
    // consider also to add matrix3d(a, b, 0, 0, c, d, 0, 0, 0, 0, 1, 0, tx, ty, 0, 1)
    var mat = transform.match(/^matrix\((.+)\)$/);
    if (mat) {
        transArr[0] = parseFloat(mat[1].split(', ')[4]);
        transArr[1] = parseFloat(mat[1].split(', ')[5]);
    }
    return transArr;
}
function createFullPortId(nodeId, portId) {
    return nodeId + "-" + portId;
}

function guidS4() {
    return Math.floor((1 + Math.random()) * 0x10000)
        .toString(16)
        .substring(1);
}
function guid() {
    // return id of format 'aaaaaaaa'-'aaaa'-'aaaa'-'aaaa'-'aaaaaaaaaaaa'
    return (guidS4() +
        guidS4() +
        '-' +
        guidS4() +
        '-' +
        guidS4() +
        '-' +
        guidS4() +
        '-' +
        guidS4() +
        guidS4() +
        guidS4());
}
function guidForcedUniqueness(checkExistence) {
    var id = guid();
    while (checkExistence(id)) {
        id = guid();
    }
    return id;
}

var LinksStore = /** @class */ (function () {
    function LinksStore(rootStore) {
        var _this = this;
        Object.defineProperty(this, "_links", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_nodesLinksCollection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_linkCreation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newLinks) {
                _this._links = new Map();
                _this._nodesLinksCollection = new Map();
                if (newLinks) {
                    var results = _this._addLinksInternal(newLinks, false);
                    _this._rootStore.callbacks.linksAdded({
                        addedLinks: results.filter(isSuccess).map(function (r) { return r.value; }),
                        failedToAddLinks: results.filter(isError),
                        importing: true,
                    });
                }
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                return Array.from(_this._links).map(function (_a) {
                    _a[0]; var value = _a[1];
                    return value.export();
                });
            }
        });
        Object.defineProperty(this, "getNodeLinks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeId) {
                var _a;
                return (_a = _this._nodesLinksCollection.get(nodeId)) !== null && _a !== void 0 ? _a : [];
            }
        });
        Object.defineProperty(this, "getLink", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (id) {
                return _this.links.get(id);
            }
        });
        Object.defineProperty(this, "getPortLinks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeId, portId) {
                var nodeLinks = _this.getNodeLinks(nodeId);
                var fullPortId = createFullPortId(nodeId, portId);
                return nodeLinks.filter(function (l) {
                    return (l.source && l.source.port.fullId === fullPortId) ||
                        (l.target && l.target.port.fullId === fullPortId);
                });
            }
        });
        Object.defineProperty(this, "addLinks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (links, rewriteIfAlreadyConnected) {
                if (rewriteIfAlreadyConnected === void 0) { rewriteIfAlreadyConnected = false; }
                var results = _this._addLinksInternal(links, rewriteIfAlreadyConnected);
                _this._rootStore.callbacks.linksAdded({
                    addedLinks: results.filter(isSuccess).map(function (r) { return r.value; }),
                    failedToAddLinks: results.filter(isError),
                    importing: false,
                });
                return results;
            }
        });
        Object.defineProperty(this, "addLink", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (link, rewriteIfAlreadyConnected) {
                if (rewriteIfAlreadyConnected === void 0) { rewriteIfAlreadyConnected = false; }
                var result = _this._addLinkInternal(link, rewriteIfAlreadyConnected);
                _this._rootStore.callbacks.linksAdded({
                    addedLinks: result.success ? [result.value] : [],
                    failedToAddLinks: result.success ? [] : [result],
                    importing: false,
                });
                return result;
            }
        });
        Object.defineProperty(this, "removeLink", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (linkId) {
                var removedLink = _this._removeLink(linkId);
                _this._rootStore.callbacks.linksRemoved({
                    removedLinks: removedLink ? [removedLink] : [],
                    failedToRemoveLinkIds: removedLink ? [] : [linkId],
                });
                return removedLink;
            }
        });
        Object.defineProperty(this, "removeLinks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (linkIds) {
                var results = _this._removeLinks(linkIds);
                _this._rootStore.callbacks.linksRemoved({
                    removedLinks: results.filter(isSuccess).map(function (r) { return r.value; }),
                    failedToRemoveLinkIds: results.filter(isError).map(function (r) { return r.value; }),
                });
                return results;
            }
        });
        Object.defineProperty(this, "removeNodeLinks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeId) {
                var linkIds = _this.getNodeLinks(nodeId).map(function (l) { return l.id; });
                _this.removeLinks(linkIds);
            }
        });
        Object.defineProperty(this, "removePortLinks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeId, portId) {
                if (!nodeId || !portId)
                    return;
                var endpointToRemove = {
                    nodeId: nodeId,
                    portId: portId,
                };
                var linkIds = _this.getNodeLinks(nodeId)
                    .filter(function (l) {
                    return linkPortEndpointsEquals(l.sourceEndpoint, endpointToRemove) ||
                        linkPortEndpointsEquals(l.targetEndpoint, endpointToRemove);
                })
                    .map(function (l) { return l.id; });
                _this.removeLinks(linkIds);
            }
        });
        Object.defineProperty(this, "validateLink", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (link, ignoreIfAlreadyConnected) {
                if (ignoreIfAlreadyConnected === void 0) { ignoreIfAlreadyConnected = false; }
                var propsValidationResult = _this.validateLinkProperties(link, ignoreIfAlreadyConnected);
                if (!propsValidationResult.success)
                    return propsValidationResult;
                var sourcePortResult = _this.getEndpointPortOrError(link.source);
                if (!sourcePortResult.success)
                    return sourcePortResult;
                var targetPortResult = _this.getEndpointPortOrError(link.target);
                if (!targetPortResult.success)
                    return targetPortResult;
                if (!ignoreIfAlreadyConnected &&
                    _this.areEndpointsConnected(link.source, link.target))
                    return errorResult("Link's endpoints are already connected");
                if (_this._rootStore.callbacks.linkValidation({
                    source: sourcePortResult.value,
                    target: targetPortResult.value,
                }) === false) {
                    return errorResult("Link's endpoints are not valid according to validation callback");
                }
                return successResult();
            }
        });
        Object.defineProperty(this, "validateLinkProperties", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (link, ignoreIfAlreadyConnected) {
                if (ignoreIfAlreadyConnected === void 0) { ignoreIfAlreadyConnected = false; }
                if (!link)
                    return errorResult("Cannot add empty");
                if (link.id && typeof link.id !== 'string')
                    return errorResult("Cannot add link with id '" + link.id + "' of type different than 'string'");
                if (!ignoreIfAlreadyConnected && link.id && _this._links.has(link.id))
                    return errorResult("Cannot add link with id '" + link.id + "' because link with this id already exists");
                if (link.source.nodeId === link.target.nodeId)
                    return errorResult("Link's endpoints are located in the same node");
                return successResult();
            }
        });
        Object.defineProperty(this, "getEndpointPortOrError", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (endpoint) {
                var node = _this._rootStore.nodesStore.getNode(endpoint.nodeId);
                if (!node)
                    return errorResult("Node '" + endpoint.nodeId + "' of link's endpoint does not exist");
                var port = node.getPort(endpoint.portId);
                if (!port)
                    return errorResult("Port with id '" + endpoint.portId + "' does not exist in the node '" + endpoint.nodeId + "'");
                return successValueResult(port);
            }
        });
        Object.defineProperty(this, "getEndpointPort", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (endpoint) {
                var _a;
                return (_a = _this._rootStore.nodesStore
                    .getNode(endpoint.nodeId)) === null || _a === void 0 ? void 0 : _a.getPort(endpoint.portId);
            }
        });
        Object.defineProperty(this, "areEndpointsConnected", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (source, target) {
                return !!_this.getLinkForEndpointsIfExists(source, target);
            }
        });
        Object.defineProperty(this, "getLinkForEndpointsIfExists", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (source, target) {
                var links = _this._nodesLinksCollection.get(source.nodeId);
                if (links) {
                    return links.find(function (l) {
                        return (linkPortEndpointsEquals(l.sourceEndpoint, source) &&
                            linkPortEndpointsEquals(l.targetEndpoint, target)) ||
                            (linkPortEndpointsEquals(l.targetEndpoint, source) &&
                                linkPortEndpointsEquals(l.sourceEndpoint, target));
                    });
                }
            }
        });
        Object.defineProperty(this, "_addLinksInternal", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (links, rewriteIfAlreadyConnected) {
                var results = links.map(function (link) {
                    return _this._addLinkInternal(link, rewriteIfAlreadyConnected);
                });
                return results;
            }
        });
        Object.defineProperty(this, "_addLinkInternal", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (link, rewriteIfAlreadyConnected) {
                var _a;
                var validationResult = _this.validateLink(link, rewriteIfAlreadyConnected);
                if (!validationResult.success) {
                    return errorValueResult(link, validationResult.error);
                }
                if (rewriteIfAlreadyConnected) {
                    var existedLink = link.id ? _this.getLink(link.id) : undefined;
                    existedLink = _this.getLinkForEndpointsIfExists(link.source, link.target);
                    if (existedLink) {
                        _this._removeLink(existedLink.id);
                    }
                }
                var newLink = new LinkState(_this._rootStore, (_a = link.id) !== null && _a !== void 0 ? _a : guidForcedUniqueness(function (id) { return _this._links.has(id); }), link);
                _this._links.set(newLink.id, newLink);
                _this._addLinkToNodeLinksCollection(newLink, link.source.nodeId);
                _this._addLinkToNodeLinksCollection(newLink, link.target.nodeId);
                return successValueResult(newLink);
            }
        });
        Object.defineProperty(this, "_addLinkToNodeLinksCollection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (link, nodeId) {
                var links = _this._nodesLinksCollection.get(nodeId);
                if (!links) {
                    _this._nodesLinksCollection.set(nodeId, [link]);
                }
                else if (!links.includes(link)) {
                    links.push(link);
                }
            }
        });
        Object.defineProperty(this, "_removeLinks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (linkIds) {
                return linkIds.map(function (id) {
                    var removedLink = _this._removeLink(id);
                    if (removedLink)
                        return successValueResult(removedLink);
                    else
                        return errorValueResult(id);
                });
            }
        });
        Object.defineProperty(this, "_removeLink", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (linkId) {
                var linkToRemove = _this._links.get(linkId);
                if (linkToRemove) {
                    var linkState = linkToRemove.export();
                    _this._removeLinkFromNodeLinksCollection(linkToRemove.id, linkToRemove.sourceEndpoint.nodeId);
                    _this._removeLinkFromNodeLinksCollection(linkToRemove.id, linkToRemove.targetEndpoint.nodeId);
                    _this._rootStore.selectionState.unselect(linkToRemove);
                    _this._links.delete(linkId);
                    return linkState;
                }
                return undefined;
            }
        });
        Object.defineProperty(this, "_removeLinkFromNodeLinksCollection", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (linkId, nodeId) {
                var collection = _this._nodesLinksCollection.get(nodeId);
                if (collection) {
                    collection = collection.filter(function (l) { return l.id !== linkId; });
                    if (collection.length > 0) {
                        _this._nodesLinksCollection.set(nodeId, collection);
                    }
                    else {
                        _this._nodesLinksCollection.delete(nodeId);
                    }
                }
            }
        });
        this._linkCreation = new LinkCreationState(rootStore);
        this.import();
        mobx.makeAutoObservable(this);
        this._rootStore = rootStore;
    }
    Object.defineProperty(LinksStore.prototype, "links", {
        get: function () {
            return this._links;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinksStore.prototype, "linkCreation", {
        get: function () {
            return this._linkCreation;
        },
        enumerable: false,
        configurable: true
    });
    return LinksStore;
}());

var NodeLabel = mobxReactLite.observer(function (_a) {
    var node = _a.node;
    return React__default["default"].createElement("div", { className: 'react_fast_diagram_NodeLabel' }, node.label ? node.label : node.id);
});

/**
 * Check each element starting from the first one in composedPath() (see https://developer.mozilla.org/en-US/docs/Web/API/Event/composedPath),
 * if exceptClassName is the first class found -> return false,
 * if className is the first class found -> return true,
 * if neither exceptClassName nor className were found -> return false
 */
var eventPathContainsClass = function (event, className, exceptClassName) {
    var typedEvent = event;
    if ('composedPath' in typedEvent) {
        var targets = typedEvent.composedPath();
        for (var i = 0; i < targets.length; i++) {
            var target = targets[i];
            if ('classList' in target) {
                var classList = target.classList;
                if (exceptClassName && classList.contains(exceptClassName)) {
                    return false;
                }
                else if (classList.contains(className)) {
                    return true;
                }
            }
        }
    }
    return false;
};
/**
 * Does gesture can be potentially a tap/click event?
 * Drag gesture will be tap/click gesture on mouse or touch release only when the drag displacement is inferior to 3 pixels.
 * See useGestures documentation for more information.
 * @param movement - state value of gesture, represent gesture offset
 */
function canDragGestureBeTapInstead(movement) {
    return Math.max(Math.abs(movement[0]), Math.abs(movement[1])) < 3;
}

var useRootStore = function () { return React.useContext(RootStoreContext); };

function useCursor(active, cursor, ref) {
    var cursorBeforeSetRef = React.useRef('');
    React.useEffect(function () {
        if (!active || !ref || !cursor || ref.style.cursor === cursor) {
            return;
        }
        cursorBeforeSetRef.current = ref.style.cursor;
        ref.style.cursor = cursor;
        return function () {
            ref.style.cursor = cursorBeforeSetRef.current;
        };
    }, [active, ref]);
}
function useDiagramCursor(active, cursor) {
    var diagramState = useRootStore().diagramState;
    var ref = diagramState.ref.current;
    useCursor(active, cursor, ref);
}

var useNodeUserInteraction = function (nodeState) {
    var rootStore = useRootStore();
    var interactionActiveRef = React.useRef(false);
    var selectOnLongTapRef = React.useRef(null);
    var cancelSelectOnLongTap = React.useCallback(function () {
        if (selectOnLongTapRef.current) {
            clearTimeout(selectOnLongTapRef.current);
            selectOnLongTapRef.current = null;
            return true;
        }
        return false;
    }, [selectOnLongTapRef]);
    var startedDragRef = React.useRef(false);
    var handlers = React.useMemo(function () { return ({
        onPointerEnter: function () {
            nodeState.hovered = true;
        },
        onPointerLeave: function () {
            nodeState.hovered = false;
        },
        onClick: function () { },
        onDrag: function (_a) {
            var pinching = _a.pinching, delta = _a.delta, movement = _a.movement, cancel = _a.cancel;
            if (!interactionActiveRef.current ||
                pinching ||
                canDragGestureBeTapInstead(movement)) {
                return;
            }
            cancelSelectOnLongTap();
            if (!nodeState.isDragEnabled ||
                // If there is another node that activated dragging
                (rootStore.dragState.isActive && !startedDragRef.current)) {
                interactionActiveRef.current = false;
                cancel();
                return;
            }
            // If somehow node was unselected during dragging. It can be connecting ports while dragging nodes, 
            // or dropped node for example
            if (rootStore.dragState.isActive &&
                !nodeState.isDragActive &&
                startedDragRef.current) {
                rootStore.dragState.stopDragging();
                startedDragRef.current = false;
                interactionActiveRef.current = false;
                cancel();
                return;
            }
            if (!nodeState.isDragActive) {
                startedDragRef.current = rootStore.dragState.startDragging(nodeState);
            }
            rootStore.dragState.dragBy(multiplyPoint(delta, 1 / rootStore.diagramState.zoom));
        },
        onDragStart: function (_a) {
            var event = _a.event, cancel = _a.cancel;
            interactionActiveRef.current =
                allowNodeInteraction(event) && !rootStore.dragState.isActive;
            if (interactionActiveRef.current) {
                cancelSelectOnLongTap();
                if (nodeState.isSelectionEnabled) {
                    selectOnLongTapRef.current = global.setTimeout(function () {
                        if (selectOnLongTapRef.current) {
                            selectOnLongTapRef.current = null;
                            // It can happen if user simultaneously tap two nodes and will start move one of them
                            if (!rootStore.dragState.isActive) {
                                rootStore.selectionState.switch(nodeState);
                            }
                        }
                    }, selectDelay$1);
                }
            }
            else {
                cancel();
            }
        },
        onDragEnd: function (_a) {
            var tap = _a.tap, shiftKey = _a.shiftKey, altKey = _a.altKey, ctrlKey = _a.ctrlKey, metaKey = _a.metaKey;
            if (interactionActiveRef.current) {
                interactionActiveRef.current = false;
                var selectLongOnTapCancelled = cancelSelectOnLongTap();
                if (startedDragRef.current) {
                    rootStore.dragState.stopDragging();
                    startedDragRef.current = false;
                }
                // selectLongOnTapCancelled means that callback in timer wasn't executed yet
                if (nodeState.isSelectionEnabled && tap && selectLongOnTapCancelled) {
                    rootStore.selectionState.switch(nodeState, !rootStore.diagramSettings.userInteraction.isCallbackMultiselectionActivated(shiftKey, altKey, ctrlKey, metaKey));
                }
            }
        },
    }); }, [nodeState, rootStore]);
    react.useGesture(handlers, {
        target: nodeState.ref,
        eventOptions: { passive: false },
        enabled: !rootStore.diagramSettings.userInteraction
            .arePointerInteractionsDisabled,
    });
    useDiagramCursor(nodeState.isDragActive, 'move');
    useCursor(nodeState.isDragActive, 'move', nodeState.ref.current);
};
var selectDelay$1 = 500;
function allowNodeInteraction(event) {
    return eventPathContainsClass(event, ENABLE_NODE_USER_INTERACTION_CLASS, DISABLE_NODE_USER_INTERACTION_CLASS);
}
var ENABLE_NODE_USER_INTERACTION_CLASS = 'react_easy_diagram_enable_node_user_interaction';
var DISABLE_NODE_USER_INTERACTION_CLASS = 'react_easy_diagram_disable_node_user_interaction';

var NodeWrapper = mobxReactLite.observer(function (_a) {
    var node = _a.node;
    var diagramSettings = useRootStore().diagramSettings;
    useNodeUserInteraction(node);
    var className = "react_fast_diagram_NodeWrapper " + ENABLE_NODE_USER_INTERACTION_CLASS;
    if (!diagramSettings.userInteraction.arePointerInteractionsDisabled) {
        // Disable touch actions as useGesture library recommends
        className += ' react_fast_diagram_touch_action_disabled';
    }
    return (React__default["default"].createElement(NodeContext.Provider, { value: node },
        React__default["default"].createElement("div", { id: node.id, className: className, style: {
                transform: "translate(" + node.position[0] + "px, " + node.position[1] + "px)",
                zIndex: node.selected ? 10 : undefined,
            }, ref: node.ref },
            React__default["default"].createElement(node.componentDefinition.component, { entity: node, settings: node.componentDefinition.settings }))));
});
var NodeContext = React__default["default"].createContext(null);

var useRelativePositionStyles = function (position, offsetFromParentCenter, offsetFromOrigin, usePortCenterPivot) {
    if (usePortCenterPivot === void 0) { usePortCenterPivot = true; }
    return React.useMemo(function () {
        if (!position)
            return {};
        var positionStyle = { position: 'absolute' };
        if (!isNumber(offsetFromParentCenter))
            offsetFromParentCenter = 0;
        if (!isPoint(offsetFromOrigin))
            offsetFromOrigin = [0, 0];
        if (position === 'left-top') {
            positionStyle.left = offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.top = offsetFromOrigin[1];
            if (usePortCenterPivot)
                positionStyle.transform = "translateX(-50%)";
        }
        else if (position === 'left-center') {
            positionStyle.left = offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.top = '50%';
            positionStyle.transform = "translate(" + (usePortCenterPivot ? '-50%' : 0) + ", calc(-50% + " + offsetFromOrigin[1] + "px))";
        }
        else if (position === 'left-bottom') {
            positionStyle.left = offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.bottom = -offsetFromOrigin[1];
            if (usePortCenterPivot)
                positionStyle.transform = "translateX(-50%)";
        }
        if (position === 'top-left') {
            positionStyle.left = offsetFromOrigin[0];
            positionStyle.top = offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translateY(-50%)";
        }
        else if (position === 'top-center') {
            positionStyle.left = '50%';
            positionStyle.transform = "translate(calc(-50% + " + offsetFromOrigin[0] + "px), " + (usePortCenterPivot ? '-50%' : 0) + ")";
            positionStyle.top = offsetFromOrigin[1] - offsetFromParentCenter;
        }
        else if (position === 'top-right') {
            positionStyle.right = -offsetFromOrigin[0];
            positionStyle.top = offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translateY(-50%)";
        }
        if (position === 'right-top') {
            positionStyle.right = -offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.top = offsetFromOrigin[1];
            if (usePortCenterPivot)
                positionStyle.transform = "translateX(50%)";
        }
        else if (position === 'right-center') {
            positionStyle.right = -offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.top = '50%';
            positionStyle.transform = "translate(" + (usePortCenterPivot ? '50%' : 0) + ", calc(-50% + " + offsetFromOrigin[1] + "px))";
        }
        else if (position === 'right-bottom') {
            positionStyle.right = -offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.bottom = -offsetFromOrigin[1];
            if (usePortCenterPivot)
                positionStyle.transform = "translateX(50%)";
        }
        if (position === 'bottom-left') {
            positionStyle.left = offsetFromOrigin[0];
            positionStyle.bottom = -offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translateY(50%)";
        }
        else if (position === 'bottom-center') {
            positionStyle.left = '50%';
            positionStyle.transform = "translate(calc(-50% + " + offsetFromOrigin[0] + "px), " + (usePortCenterPivot ? '50%' : 0) + ")";
            positionStyle.bottom = -offsetFromOrigin[1] - offsetFromParentCenter;
        }
        else if (position === 'bottom-right') {
            positionStyle.right = -offsetFromOrigin[0];
            positionStyle.bottom = -offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translateY(50%)";
        }
        if (position === 'diagonal-left-top') {
            positionStyle.left = offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.top = offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translate(-50%, -50%)";
        }
        else if (position === 'diagonal-right-top') {
            positionStyle.right = -offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.top = offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translate(50%, -50%)";
        }
        else if (position === 'diagonal-right-bottom') {
            positionStyle.right = -offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.bottom = -offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translate(50%, 50%)";
        }
        else if (position === 'diagonal-left-bottom') {
            positionStyle.left = offsetFromOrigin[0] - offsetFromParentCenter;
            positionStyle.bottom = -offsetFromOrigin[1] - offsetFromParentCenter;
            if (usePortCenterPivot)
                positionStyle.transform = "translate(-50%, 50%)";
        }
        return positionStyle;
    }, [position, offsetFromParentCenter, offsetFromOrigin, usePortCenterPivot]);
};
var portPositionValues = [
    'left-top',
    'left-center',
    'left-bottom',
    'top-left',
    'top-center',
    'top-right',
    'right-top',
    'right-center',
    'right-bottom',
    'bottom-left',
    'bottom-center',
    'bottom-right',
    'diagonal-left-top',
    'diagonal-right-top',
    'diagonal-right-bottom',
    'diagonal-left-bottom',
];

var usePortUserInteraction = function (portState) {
    var _a = useRootStore(), linkCreation = _a.linksStore.linkCreation, diagramState = _a.diagramState, diagramSettings = _a.diagramSettings;
    var handlers = React.useMemo(function () { return ({
        onDrag: function (_a) {
            var _b;
            var delta = _a.delta;
            if (!portState || !portState.dragging)
                return;
            var parentScale = diagramState.zoom;
            (_b = linkCreation.target) === null || _b === void 0 ? void 0 : _b.translateBy(multiplyPoint(delta, 1 / parentScale));
        },
        onDragStart: function (_a) {
            var event = _a.event, xy = _a.xy;
            if (!portState || !portState.isConnectionEnabled)
                return;
            var portHtmlElement = event.target;
            // Important! Otherwise on touch display onPointerEnter will not work!
            portHtmlElement.releasePointerCapture(event.pointerId);
            var clientRect = portHtmlElement.getBoundingClientRect();
            var pointOnPort = subtractPoints(xy, [clientRect.x, clientRect.y]);
            if (linkCreation.startLinking(portState, pointOnPort)) {
                portState.dragging = true;
            }
        },
        onDragEnd: function () {
            if (!portState)
                return;
            portState.dragging = false;
            linkCreation.stopLinking();
        },
        onPointerEnter: function () {
            if (!portState)
                return;
            if (portState.isConnectionEnabled) {
                portState.hovered = true;
                linkCreation.setTargetPortCandidate(portState);
            }
        },
        onPointerLeave: function () {
            if (!portState)
                return;
            portState.hovered = false;
            linkCreation.resetTargetPortCandidate(portState);
        },
    }); }, [portState, linkCreation, diagramState]);
    // Temporary bug fix when pointer events handlers are not reassigned.
    // See https://github.com/pmndrs/use-gesture/issues/263 and https://github.com/pmndrs/@use-gesture/react/issues/264
    // There could be some other bugs related to handlers object replacing
    var bind = react.useGesture(handlers, {
        eventOptions: { passive: false },
        drag: { pointer: { capture: false } },
        enabled: !diagramSettings.userInteraction.arePointerInteractionsDisabled
    });
    useDiagramCursor(!!(portState === null || portState === void 0 ? void 0 : portState.dragging), 'pointer');
    return {
        active: !!(portState === null || portState === void 0 ? void 0 : portState.dragging),
        bind: bind,
    };
};

var Port = mobxReactLite.observer(function (props) {
    var diagramSettings = useRootStore().diagramSettings;
    var node = React.useContext(NodeContext); // node should already exist
    var portState = node.getPort(props.id);
    var positionStyles = useRelativePositionStyles(portState === null || portState === void 0 ? void 0 : portState.position, portState === null || portState === void 0 ? void 0 : portState.offsetFromNodeCenter, portState === null || portState === void 0 ? void 0 : portState.offsetFromOrigin);
    var bind = usePortUserInteraction(portState).bind;
    React.useEffect(function () {
        // Prevent from recalculating on first load
        if (portState && portState.offsetRecalculationRequested > 0) {
            portState === null || portState === void 0 ? void 0 : portState.recalculateOffsetImmediately();
        }
    }, [portState, portState === null || portState === void 0 ? void 0 : portState.offsetRecalculationRequested]);
    if (!portState) {
        return null;
    }
    var className = DISABLE_NODE_USER_INTERACTION_CLASS;
    if (!diagramSettings.userInteraction.arePointerInteractionsDisabled) {
        // Disable touch actions as useGesture library recommends
        className += ' react_fast_diagram_touch_action_disabled';
    }
    return (React__default["default"].createElement("div", __assign({ style: positionStyles, id: portState.fullId, className: className, ref: portState.ref, key: portState.fullId }, bind()),
        React__default["default"].createElement(portState.componentDefinition.component, { entity: portState, settings: portState.componentDefinition.settings })));
});

var NodeDefault = mobxReactLite.observer(function (_a) {
    var entity = _a.entity, settings = _a.settings;
    var stylingOptions = React.useMemo(function () { return ({
        removeDefaultClasses: settings === null || settings === void 0 ? void 0 : settings.removeDefaultClasses,
        baseState: 'base',
        classes: settings === null || settings === void 0 ? void 0 : settings.classes,
        defaultClasses: defaultNodeClasses,
        style: settings === null || settings === void 0 ? void 0 : settings.style,
        spareStates: { 'selected-hovered': ['selected', 'hovered'] },
    }); }, [settings]);
    var state = 'base';
    if (entity.selected && entity.hovered)
        state = 'selected-hovered';
    else if (entity.selected)
        state = 'selected';
    else if (entity.hovered)
        state = 'hovered';
    var styling = useStyling(stylingOptions, state);
    return (React__default["default"].createElement("div", { className: styling.className, style: styling.style },
        (settings === null || settings === void 0 ? void 0 : settings.innerNode) && React__default["default"].createElement(settings.innerNode, { node: entity }),
        Array.isArray(settings === null || settings === void 0 ? void 0 : settings.ports) && (settings === null || settings === void 0 ? void 0 : settings.ports.map(function (p) { return React__default["default"].createElement(Port, { id: p.id, key: p.id }); }))));
});
var defaultNodeClasses = {
    base: ['react_fast_diagram_NodeDefault'],
    hovered: ['react_fast_diagram_NodeDefault_Hovered'],
    selected: ['react_fast_diagram_NodeDefault_Selected'],
};
function createNode(settings) {
    return {
        component: NodeDefault,
        settings: __assign({ innerNode: NodeLabel }, settings),
    };
}
var createInputOutputHorizontalNode = function (settings) {
    return createNode(__assign(__assign({}, settings), { ports: [
            { id: 'input', type: 'input', position: 'left-center' },
            { id: 'output', type: 'output', position: 'right-center' },
        ] }));
};
var createInputOutputVerticalNode = function (settings) {
    return createNode(__assign(__assign({}, settings), { ports: [
            { id: 'input', type: 'input', position: 'top-center' },
            { id: 'output', type: 'output', position: 'bottom-center' },
        ] }));
};
var createInputHorizontalNode = function (settings) {
    return createNode(__assign(__assign({}, settings), { ports: [{ id: 'input', type: 'input', position: 'left-center' }] }));
};
var createInputVerticalNode = function (settings) {
    return createNode(__assign(__assign({}, settings), { ports: [{ id: 'input', type: 'input', position: 'top-center' }] }));
};
var createOutputHorizontalNode = function (settings) {
    return createNode(__assign(__assign({}, settings), { ports: [{ id: 'output', type: 'output', position: 'right-center' }] }));
};
var createOutputVerticalNode = function (settings) {
    return createNode(__assign(__assign({}, settings), { ports: [{ id: 'output', type: 'output', position: 'bottom-center' }] }));
};
var createStarNode = function (settings) {
    return createNode(__assign(__assign({}, settings), { ports: [
            { id: 'left', position: 'left-center' },
            { id: 'top', position: 'top-center' },
            { id: 'right', position: 'right-center' },
            { id: 'bottom', position: 'bottom-center' },
        ] }));
};

var NodesSettings = /** @class */ (function () {
    function NodesSettings() {
        var _a;
        var _this = this;
        Object.defineProperty(this, "_visualComponents", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new VisualComponents((_a = {},
                _a[COMPONENT_DEFAULT_TYPE] = createNode({ ports: [] }),
                _a.input_output_horizontal = createInputOutputHorizontalNode(),
                _a.input_output_vertical = createInputOutputVerticalNode(),
                _a.input_vertical = createInputVerticalNode(),
                _a.input_horizontal = createInputHorizontalNode(),
                _a.output_vertical = createOutputVerticalNode(),
                _a.output_horizontal = createOutputHorizontalNode(),
                _a.star = createStarNode(),
                _a))
        });
        Object.defineProperty(this, "_gridSnap", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (obj) {
                _this._visualComponents.import(obj);
                _this.setGridSnap(obj === null || obj === void 0 ? void 0 : obj.gridSnap);
            }
        });
        Object.defineProperty(this, "setGridSnap", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (gridSnap) {
                if (!gridSnap) {
                    _this._gridSnap = null;
                }
                else if (typeof gridSnap === 'number') {
                    _this._gridSnap = [gridSnap, gridSnap];
                }
                else if (Array.isArray(gridSnap) && gridSnap.length === 2) {
                    _this._gridSnap = gridSnap;
                }
            }
        });
        this.setGridSnap();
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(NodesSettings.prototype, "visualComponents", {
        get: function () {
            return this._visualComponents;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodesSettings.prototype, "gridSnap", {
        get: function () {
            return this._gridSnap;
        },
        enumerable: false,
        configurable: true
    });
    return NodesSettings;
}());

var generateTransform = function (translate, scale) {
    var translatePart = "translate(" + translate[0] + "px, " + translate[1] + "px)";
    if (scale) {
        var scalePart = "scale(" + scale + ")";
        return translatePart + ' ' + scalePart;
    }
    else {
        return translatePart;
    }
};
var areTransformationsEqual = function (a, b) {
    return a === b ||
        (a && b && a.zoom === b.zoom && arePointsEqual(a.offset, b.offset));
};

var NodeState = /** @class */ (function () {
    function NodeState(rootStore, id, state) {
        var _this = this;
        Object.defineProperty(this, "_id", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_label", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_position", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_ports", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_ref", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_type", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_selected", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_hovered", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_data", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_isSelectionEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_isDragEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_isDragActive", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newState) {
                var _a;
                _this._setPosition((_a = newState === null || newState === void 0 ? void 0 : newState.position) !== null && _a !== void 0 ? _a : [0, 0]);
                _this._setType(newState === null || newState === void 0 ? void 0 : newState.type);
                _this._setData(newState === null || newState === void 0 ? void 0 : newState.data);
                _this._setLabel(newState === null || newState === void 0 ? void 0 : newState.label);
                _this.setPorts(newState === null || newState === void 0 ? void 0 : newState.ports);
                _this._setIsSelectionEnabled(newState === null || newState === void 0 ? void 0 : newState.isSelectionEnabled);
                _this._setIsDragEnabled(newState === null || newState === void 0 ? void 0 : newState.isDragEnabled);
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                var _a, _b;
                return (__assign({}, deepCopy({
                    id: _this._id,
                    label: _this._label,
                    position: _this._position,
                    ports: Array.from(_this._ports).map(function (_a) {
                        _a[0]; var p = _a[1];
                        return p.export();
                    }),
                    type: _this._type,
                    data: _this.data,
                    isSelectionEnabled: (_a = _this._isSelectionEnabled) !== null && _a !== void 0 ? _a : undefined,
                    isDragEnabled: (_b = _this._isDragEnabled) !== null && _b !== void 0 ? _b : undefined,
                })));
            }
        });
        Object.defineProperty(this, "setLabel", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var change = _this._setLabel(value);
                if (change) {
                    _this._rootStore.callbacks.nodeLabelChanged(_this, change);
                }
                return change;
            }
        });
        Object.defineProperty(this, "_setLabel", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var valueToSet = value !== null && value !== void 0 ? value : undefined;
                if (_this._label === valueToSet) {
                    return undefined;
                }
                var oldValue = _this._label;
                _this._label = valueToSet;
                return {
                    oldValue: oldValue,
                    newValue: _this._label,
                };
            }
        });
        /**
         * @param newPosition - new position
         * @param ignoreSnapping - do not take into account snapping to grid
         * @returns `undefined` if position did not change
         */
        Object.defineProperty(this, "setPosition", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newPosition, ignoreSnapping) {
                if (ignoreSnapping === void 0) { ignoreSnapping = false; }
                var change = _this._setPosition(newPosition, ignoreSnapping);
                if (change) {
                    _this._rootStore.callbacks.nodePositionChanged(_this, change);
                }
                return change;
            }
        });
        Object.defineProperty(this, "_setPosition", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newPosition, ignoreSnapping) {
                if (ignoreSnapping === void 0) { ignoreSnapping = false; }
                var snap = _this._rootStore.nodesSettings.gridSnap;
                if (!ignoreSnapping && snap) {
                    newPosition = [
                        snapPosition(newPosition[0], snap[0]),
                        snapPosition(newPosition[1], snap[1]),
                    ];
                }
                if (!arePointsEqual(newPosition, _this._position)) {
                    var oldPos = _this._position;
                    _this._position = newPosition;
                    return {
                        oldValue: oldPos,
                        newValue: _this._position,
                    };
                }
                else
                    return undefined;
            }
        });
        /**
         * @param vector - vector to move node by
         * @param ignoreSnapping - do not take into account snapping to grid
         * @returns remainder in case snap to grid is turned on. For example if vector
         * would be [3,9], node current position [10,10] and snap [5,5],
         * the node position would be set to [10,15] and remainder equals [3,4]
         */
        Object.defineProperty(this, "moveBy", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (vector, ignoreSnapping) {
                if (ignoreSnapping === void 0) { ignoreSnapping = false; }
                var newPos = addPoints(_this.position, vector);
                var remainder = undefined;
                var snap = _this._rootStore.nodesSettings.gridSnap;
                if (!ignoreSnapping && snap) {
                    var res1 = snapMoveByVector(_this.position[0], vector[0], snap[0]);
                    var res2 = snapMoveByVector(_this.position[1], vector[1], snap[1]);
                    remainder = [res1.remainder, res2.remainder];
                    newPos = [res1.value, res2.value];
                }
                _this.setPosition(newPos, true);
                return remainder;
            }
        });
        Object.defineProperty(this, "setType", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var change = _this._setType(value);
                if (change) {
                    _this._rootStore.callbacks.nodeTypeChanged(_this, change);
                }
                return change;
            }
        });
        Object.defineProperty(this, "_setType", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var valueToSet = value !== null && value !== void 0 ? value : undefined;
                if (_this._type === valueToSet) {
                    return undefined;
                }
                var oldValue = _this._type;
                _this._type = valueToSet;
                return {
                    oldValue: oldValue,
                    newValue: _this._type,
                };
            }
        });
        Object.defineProperty(this, "setData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var change = _this._setData(value);
                if (change) {
                    _this._rootStore.callbacks.nodeDataChanged(_this, change);
                }
                return change;
            }
        });
        Object.defineProperty(this, "_setData", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                if (_this._data === value) {
                    return undefined;
                }
                var oldValue = _this._data;
                _this._data = value !== null && value !== void 0 ? value : undefined;
                return {
                    oldValue: oldValue,
                    newValue: _this._data,
                };
            }
        });
        Object.defineProperty(this, "setPorts", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodePorts) {
                var _a, _b, _c, _d;
                var componentPortsIds = (_c = (_b = (_a = _this.componentDefinition.settings) === null || _a === void 0 ? void 0 : _a.ports) === null || _b === void 0 ? void 0 : _b.map(function (p) { return p.id; })) !== null && _c !== void 0 ? _c : [];
                var nodePortsIds = (_d = nodePorts === null || nodePorts === void 0 ? void 0 : nodePorts.map(function (p) { return p.id; })) !== null && _d !== void 0 ? _d : [];
                var portsIds = new Set(__spreadArrays(componentPortsIds, nodePortsIds));
                _this._ports = new Map();
                portsIds.forEach(function (id) {
                    return _this._ports.set(id, _this._createPortState(id, nodePorts === null || nodePorts === void 0 ? void 0 : nodePorts.find(function (p) { return p.id === id; })));
                });
            }
        });
        Object.defineProperty(this, "getPort", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (portId) {
                if (portId) {
                    return _this._ports.get(portId);
                }
                else
                    return undefined;
            }
        });
        Object.defineProperty(this, "addPort", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (port) {
                if (!port || _this._ports.get(port.id)) {
                    return errorResult();
                }
                var newPort = _this._createPortState(port.id, port);
                _this._ports.set(newPort.id, newPort);
                return successValueResult(newPort);
            }
        });
        Object.defineProperty(this, "removePort", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (portId) {
                if (portId && _this._ports.get(portId)) {
                    _this._ports.delete(portId);
                    _this._rootStore.linksStore.removePortLinks(_this._id, portId);
                    return true;
                }
                return false;
            }
        });
        Object.defineProperty(this, "getPortOrThrowException", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (portId) {
                var port = _this.getPort(portId);
                if (port)
                    return port;
                else
                    throw "Port with id '" + portId + "' does not exist in the node '" + _this._id + "'";
            }
        });
        Object.defineProperty(this, "_createPortState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (id, state) {
                return new PortState(_this._rootStore, _this, id, state);
            }
        });
        Object.defineProperty(this, "recalculatePortsOffset", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                _this._ports.forEach(function (p) { return p.recalculateOffset(); });
            }
        });
        Object.defineProperty(this, "setIsSelectionEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var change = _this._setIsSelectionEnabled(value);
                if (change) {
                    _this._rootStore.callbacks.nodeIsSelectionEnabledChanged(_this, change);
                }
                return change;
            }
        });
        Object.defineProperty(this, "_setIsSelectionEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var valueToSet = isBoolean(value) ? value : undefined;
                if (_this._isSelectionEnabled === valueToSet) {
                    return undefined;
                }
                var oldValue = _this._isSelectionEnabled;
                _this._isSelectionEnabled = valueToSet;
                return {
                    oldValue: oldValue,
                    newValue: _this._isSelectionEnabled,
                };
            }
        });
        Object.defineProperty(this, "setIsDragEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var change = _this._setIsDragEnabled(value);
                if (change) {
                    _this._rootStore.callbacks.nodeIsDragEnabledChanged(_this, change);
                }
                return change;
            }
        });
        Object.defineProperty(this, "_setIsDragEnabled", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (value) {
                var valueToSet = isBoolean(value) ? value : undefined;
                if (_this._isDragEnabled === valueToSet) {
                    return undefined;
                }
                var oldValue = _this._isDragEnabled;
                _this._isDragEnabled = valueToSet;
                return {
                    oldValue: oldValue,
                    newValue: _this._isDragEnabled,
                };
            }
        });
        this._rootStore = rootStore;
        this._id = id;
        this._ref = new HtmlElementRefState(null, rootStore.diagramState);
        this._selected = false;
        this._hovered = false;
        this._isDragActive = false;
        this.import(state);
        mobx.makeAutoObservable(this, {
            // @ts-ignore
            _rootStore: false,
        });
        mobx.reaction(function () { return [_this._id, _this._label, _this._data, _this._type, _this._ports]; }, function () {
            _this.ref.recalculateSizeAndPosition();
            _this.recalculatePortsOffset();
        });
    }
    Object.defineProperty(NodeState.prototype, "id", {
        get: function () {
            return this._id;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "label", {
        get: function () {
            return this._label;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "position", {
        get: function () {
            return this._position;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "type", {
        get: function () {
            var _a;
            return (_a = this._type) !== null && _a !== void 0 ? _a : COMPONENT_DEFAULT_TYPE;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "hovered", {
        get: function () {
            return this._hovered;
        },
        set: function (value) {
            this._hovered = value;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "data", {
        get: function () {
            return this._data;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "ref", {
        get: function () {
            return this._ref;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "ports", {
        get: function () {
            return this._ports;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "connectedExternalPorts", {
        get: function () {
            var keyValues = Object.values(this.ports).map(function (p) { return [
                p.id,
                p.connectedPorts,
            ]; });
            return Object.fromEntries(keyValues);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "connectedLinks", {
        get: function () {
            return this._rootStore.linksStore.getNodeLinks(this._id);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "transformString", {
        get: function () {
            return generateTransform(this._position);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "componentDefinition", {
        get: function () {
            var visualComponents = this._rootStore.nodesSettings.visualComponents;
            return visualComponents.getComponent(this.type);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "selected", {
        get: function () {
            return this._selected;
        },
        set: function (value) {
            this._selected = value;
            if (!value) {
                this.isDragActive = false;
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "isSelectionEnabled", {
        get: function () {
            return this._isSelectionEnabled === undefined
                ? this._rootStore.diagramSettings.userInteraction.nodeSelection
                : this._isSelectionEnabled;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "isDragEnabled", {
        get: function () {
            return ((this._isDragEnabled === undefined
                ? this._rootStore.diagramSettings.userInteraction.nodeDrag
                : this._isDragEnabled) && this.isSelectionEnabled);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NodeState.prototype, "isDragActive", {
        get: function () {
            return this._isDragActive;
        },
        set: function (value) {
            if (this._isDragActive != value) {
                this._isDragActive = value;
            }
        },
        enumerable: false,
        configurable: true
    });
    return NodeState;
}());
function snapPosition(pos, snap) {
    var mod = pos % snap;
    if (Math.abs(mod) > snap / 2)
        return pos + snap * Math.sign(mod) - mod;
    else
        return pos - mod;
}
function snapMoveByVector(pos, vec, snapValue) {
    if (vec === 0)
        return { value: pos, remainder: 0 };
    var result = 0;
    var desiredPos = pos + vec;
    var frac = Math.trunc(desiredPos / snapValue);
    if ((vec < 0 && desiredPos > 0) || (vec > 0 && desiredPos < 0)) {
        frac += 1 * Math.sign(desiredPos);
    }
    if (frac === -0)
        frac = 0;
    result = frac * snapValue;
    if ((vec < 0 && result > pos) || (vec > 0 && result < pos)) {
        return { value: pos, remainder: vec };
    }
    else
        return { value: result, remainder: pos - result + vec };
}

var NodesStore = /** @class */ (function () {
    function NodesStore(rootStore) {
        var _this = this;
        Object.defineProperty(this, "_nodes", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new Map()
        });
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (newNodes) {
                _this._nodes = new Map();
                if (newNodes) {
                    var results = _this._addNodesInternal(newNodes, false);
                    _this._rootStore.callbacks.nodesAdded({
                        addedNodes: results.filter(isSuccess).map(function (r) { return r.value; }),
                        failedToAddNodes: results.filter(isError),
                        importing: true,
                    });
                }
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                return Array.from(_this._nodes).map(function (_a) {
                    _a[0]; var value = _a[1];
                    return value.export();
                });
            }
        });
        Object.defineProperty(this, "addNodes", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodes, rewriteIfExists) {
                if (rewriteIfExists === void 0) { rewriteIfExists = false; }
                var results = _this._addNodesInternal(nodes, rewriteIfExists);
                _this._rootStore.callbacks.nodesAdded({
                    addedNodes: results.filter(isSuccess).map(function (r) { return r.value; }),
                    failedToAddNodes: results.filter(isError),
                    importing: false,
                });
                return results;
            }
        });
        Object.defineProperty(this, "_addNodesInternal", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodes, rewriteIfExists) {
                var results = nodes.map(function (node) {
                    return _this._addNodeInternal(node, rewriteIfExists);
                });
                return results;
            }
        });
        Object.defineProperty(this, "addNode", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, rewriteIfExists) {
                if (rewriteIfExists === void 0) { rewriteIfExists = false; }
                var result = _this._addNodeInternal(node, rewriteIfExists);
                _this._rootStore.callbacks.nodesAdded({
                    addedNodes: result.success ? [result.value] : [],
                    failedToAddNodes: result.success ? [] : [result],
                    importing: false,
                });
                return result;
            }
        });
        Object.defineProperty(this, "_addNodeInternal", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (node, rewriteIfExists) {
                var _a;
                if (!node)
                    return errorValueResult(node, 'Node object is null or undefined');
                if (!rewriteIfExists && node.id && _this._nodes.has(node.id))
                    return errorValueResult(node, "Node with id '" + node.id + "' already exists");
                var newNode = new NodeState(_this._rootStore, (_a = node.id) !== null && _a !== void 0 ? _a : guidForcedUniqueness(function (id) { return _this._nodes.has(id); }), node);
                _this._nodes.set(newNode.id, newNode);
                return successValueResult(newNode);
            }
        });
        Object.defineProperty(this, "removeNodes", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeIds) {
                if (!Array.isArray(nodeIds) || nodeIds.length == 0)
                    return [];
                var results = nodeIds.map(function (id) {
                    var removedNode = _this._removeNode(id);
                    if (removedNode)
                        return successValueResult(removedNode);
                    else
                        return errorValueResult(id);
                });
                _this._rootStore.callbacks.nodesRemoved({
                    removedNodes: results.filter(isSuccess).map(function (r) { return r.value; }),
                    failedToRemoveNodeIds: results.filter(isError).map(function (r) { return r.value; }),
                });
                return results;
            }
        });
        Object.defineProperty(this, "removeNode", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeId) {
                var removedNode = _this._removeNode(nodeId);
                _this._rootStore.callbacks.nodesRemoved({
                    removedNodes: removedNode ? [removedNode] : [],
                    failedToRemoveNodeIds: removedNode ? [] : [nodeId],
                });
                return removedNode;
            }
        });
        Object.defineProperty(this, "_removeNode", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeId) {
                var node = _this._nodes.get(nodeId);
                if (node) {
                    var nodeState = node.export();
                    _this._rootStore.linksStore.removeNodeLinks(nodeId);
                    _this._rootStore.selectionState.unselect(node);
                    _this._nodes.delete(nodeId);
                    return nodeState;
                }
                return undefined;
            }
        });
        Object.defineProperty(this, "getNode", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeId) {
                return _this._nodes.get(nodeId);
            }
        });
        /**
         * @returns Values are calculated without zoom taking into account, that is, the same as zoom would be '1'
         */
        Object.defineProperty(this, "getNodesBoundingBox", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                var topLeftCorner = [
                    Number.POSITIVE_INFINITY,
                    Number.POSITIVE_INFINITY,
                ];
                var bottomRightCorner = [
                    Number.NEGATIVE_INFINITY,
                    Number.NEGATIVE_INFINITY,
                ];
                _this._nodes.forEach(function (node) {
                    var _a;
                    var pos = node.position;
                    var size = (_a = node.ref.sizeExcludingZoom) !== null && _a !== void 0 ? _a : [0, 0];
                    topLeftCorner = [
                        Math.min(topLeftCorner[0], pos[0]),
                        Math.min(topLeftCorner[1], pos[1]),
                    ];
                    bottomRightCorner = [
                        Math.max(bottomRightCorner[0], pos[0] + size[0]),
                        Math.max(bottomRightCorner[1], pos[1] + size[1]),
                    ];
                });
                if (_this._nodes.size == 0) {
                    topLeftCorner = [0, 0];
                    bottomRightCorner = [100, 100];
                }
                return {
                    topLeftCorner: topLeftCorner,
                    bottomRightCorner: bottomRightCorner,
                    size: subtractPoints(bottomRightCorner, topLeftCorner),
                };
            }
        });
        mobx.makeAutoObservable(this);
        this._rootStore = rootStore;
    }
    Object.defineProperty(NodesStore.prototype, "nodes", {
        get: function () {
            return this._nodes;
        },
        enumerable: false,
        configurable: true
    });
    return NodesStore;
}());

var PortInnerDefault = mobxReactLite.observer(function (_a) {
    var entity = _a.entity, settings = _a.settings;
    var stylingOptions = React.useMemo(function () { return ({
        removeDefaultClasses: settings === null || settings === void 0 ? void 0 : settings.removeDefaultClasses,
        baseState: 'base',
        classes: settings === null || settings === void 0 ? void 0 : settings.classes,
        defaultClasses: defaultPortInnerClasses,
        style: settings === null || settings === void 0 ? void 0 : settings.style,
    }); }, [settings]);
    var state = 'base';
    if (entity.dragging)
        state = 'dragging';
    else if (entity.hovered && entity.validForConnection)
        state = 'hovered';
    else if (entity.hovered && !entity.validForConnection)
        state = 'invalid';
    else if (entity.node.selected)
        state = 'node-selected';
    else if (entity.node.hovered)
        state = 'node-hovered';
    var styling = useStyling(stylingOptions, state);
    return React__default["default"].createElement("div", { className: styling.className, style: styling.style });
});
var defaultPortInnerClasses = {
    base: ['react_fast_diagram_PortInnerDefault'],
    hovered: ['react_fast_diagram_PortInnerDefault_Hovered'],
    dragging: ['react_fast_diagram_PortInnerDefault_Dragging'],
    invalid: ['react_fast_diagram_PortInnerDefault_Invalid'],
    'node-hovered': ['react_fast_diagram_PortInnerDefault_NodeHovered'],
    'node-selected': ['react_fast_diagram_PortInnerDefault_NodeSelected'],
};
function createPortInnerDefault(settings) {
    return {
        component: PortInnerDefault,
        settings: settings,
    };
}

var PortsSettings = /** @class */ (function () {
    function PortsSettings() {
        var _a;
        var _this = this;
        Object.defineProperty(this, "_portVisualComponents", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new VisualComponents((_a = {},
                _a[COMPONENT_DEFAULT_TYPE] = createPortInnerDefault(),
                _a))
        });
        Object.defineProperty(this, "import", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (obj) {
                _this.portVisualComponents.import(obj);
            }
        });
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(PortsSettings.prototype, "portVisualComponents", {
        get: function () {
            return this._portVisualComponents;
        },
        enumerable: false,
        configurable: true
    });
    return PortsSettings;
}());

var SelectionState = /** @class */ (function () {
    function SelectionState() {
        var _this = this;
        Object.defineProperty(this, "_selectedItems", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new Set()
        });
        Object.defineProperty(this, "select", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (item, unselectOther) {
                if (unselectOther === void 0) { unselectOther = false; }
                if (unselectOther)
                    _this.unselectAll();
                if (!_this._selectedItems.has(item)) {
                    item.selected = true;
                    _this._selectedItems.add(item);
                    return true;
                }
                else
                    return false;
            }
        });
        Object.defineProperty(this, "switch", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (item, unselectOtherOnSelection) {
                if (unselectOtherOnSelection === void 0) { unselectOtherOnSelection = false; }
                if (item.selected) {
                    _this.unselect(item);
                }
                else {
                    _this.select(item, unselectOtherOnSelection);
                }
            }
        });
        Object.defineProperty(this, "unselect", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (item) {
                if (_this._selectedItems.has(item)) {
                    item.selected = false;
                    _this._selectedItems.delete(item);
                    return true;
                }
                else
                    return false;
            }
        });
        Object.defineProperty(this, "unselectAll", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                _this._selectedItems.forEach(function (i) { return (i.selected = false); });
                _this._selectedItems.clear();
            }
        });
        Object.defineProperty(this, "unselectItems", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (itemsToClear) {
                itemsToClear.forEach(function (i) { return _this.unselect(i); });
            }
        });
        mobx.makeAutoObservable(this);
    }
    Object.defineProperty(SelectionState.prototype, "selectedItems", {
        get: function () {
            return Array.from(this._selectedItems);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SelectionState.prototype, "selectedNodes", {
        get: function () {
            return this.selectedItems.filter(function (i) { return i instanceof NodeState; });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SelectionState.prototype, "selectedLinks", {
        get: function () {
            return this.selectedItems.filter(function (i) { return i instanceof LinkState; });
        },
        enumerable: false,
        configurable: true
    });
    return SelectionState;
}());

/**
 * Encapsulate logic for dragging mechanism. Right now only nodes are supposed to be dragged.
 */
var DragState = /** @class */ (function () {
    function DragState(selectionState, callbacks) {
        var _this = this;
        Object.defineProperty(this, "_nodesBeingDragged", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new Set()
        });
        // In case the snap to grid option is enabled in settings
        Object.defineProperty(this, "_remaindersFromDrags", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new Map()
        });
        Object.defineProperty(this, "_selectionState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_callbacks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "startDragging", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodeToDrag) {
                if (!nodeToDrag.isDragEnabled || _this.isActive)
                    return false;
                if (nodeToDrag.selected) {
                    _this._selectionState.unselectItems(_this._selectionState.selectedItems.filter(function (i) { return i instanceof NodeState && !i.isDragEnabled; }));
                }
                else {
                    _this._selectionState.unselectAll();
                    _this._selectionState.select(nodeToDrag);
                }
                _this._selectionState.selectedNodes.forEach(function (n) {
                    n.isDragActive = true;
                    _this._nodesBeingDragged.add(n);
                    // Force snapping to grid to prevent from desynchronized dragging if some of nodes positions were
                    // set by ignoring grid
                    n.setPosition(n.position);
                });
                _this._callbacks.dragStarted({
                    nodes: _this._selectionState.selectedNodes,
                });
                return true;
            }
        });
        /**
         * Drag by a difference between previous coordinate and current
         * @param delta vector to drag by which takes into account diagram zoom
         */
        Object.defineProperty(this, "dragBy", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (delta) {
                _this._nodesBeingDragged.forEach(function (n) {
                    var vectorWithRemainder = addPoints(delta, _this._remaindersFromDrags.get(n.id));
                    var newRemainder = n.moveBy(vectorWithRemainder);
                    _this._remaindersFromDrags.set(n.id, newRemainder);
                });
                _this._callbacks.drag({
                    nodes: _this._selectionState.selectedNodes,
                    delta: delta,
                });
            }
        });
        Object.defineProperty(this, "stopDragging", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () {
                _this._nodesBeingDragged.forEach(function (n) { return (n.isDragActive = false); });
                _this._nodesBeingDragged.clear();
                _this._remaindersFromDrags.clear();
                _this._callbacks.dragEnded({
                    nodes: _this._selectionState.selectedNodes,
                });
            }
        });
        mobx.makeAutoObservable(this);
        this._selectionState = selectionState;
        this._callbacks = callbacks;
    }
    Object.defineProperty(DragState.prototype, "isActive", {
        get: function () {
            return this._nodesBeingDragged.size !== 0;
        },
        enumerable: false,
        configurable: true
    });
    return DragState;
}());

var CommandExecutor = /** @class */ (function () {
    function CommandExecutor(rootStore) {
        var _this = this;
        Object.defineProperty(this, "_rootStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "execute", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (command) {
                command.execute(_this._rootStore);
            }
        });
        mobx.makeAutoObservable(this);
        this._rootStore = rootStore;
    }
    return CommandExecutor;
}());

var RootStore = /** @class */ (function () {
    function RootStore() {
        var _this = this;
        Object.defineProperty(this, "_diagramState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_nodesStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_linksStore", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_selectionState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_dragState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_commandExecutor", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_diagramSettings", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_nodesSettings", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_portsSettings", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_linksSettings", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_callbacks", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "importState", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (nodes, links) {
                _this._nodesStore.import(nodes);
                _this._linksStore.import(links);
                _this._diagramState.reportWhenImportedStateRendered();
            }
        });
        Object.defineProperty(this, "export", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function () { return ({
                nodes: _this._nodesStore.export(),
                links: _this._linksStore.export(),
            }); }
        });
        Object.defineProperty(this, "importSettings", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: function (settings) {
                _this._diagramSettings.import(settings === null || settings === void 0 ? void 0 : settings.diagram);
                _this._nodesSettings.import(settings === null || settings === void 0 ? void 0 : settings.nodes);
                _this._linksSettings.import(settings === null || settings === void 0 ? void 0 : settings.links);
                _this._portsSettings.import(settings === null || settings === void 0 ? void 0 : settings.ports);
                _this._callbacks.import(settings === null || settings === void 0 ? void 0 : settings.callbacks);
            }
        });
        this._diagramSettings = new DiagramSettings();
        this._nodesSettings = new NodesSettings();
        this._linksSettings = new LinksSettings();
        this._portsSettings = new PortsSettings();
        this._callbacks = new Callbacks(this);
        this._diagramState = new DiagramState(this);
        this._commandExecutor = new CommandExecutor(this);
        this._nodesStore = new NodesStore(this);
        this._linksStore = new LinksStore(this);
        this._selectionState = new SelectionState();
        this._dragState = new DragState(this._selectionState, this._callbacks);
    }
    Object.defineProperty(RootStore.prototype, "diagramState", {
        get: function () {
            return this._diagramState;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "nodesStore", {
        get: function () {
            return this._nodesStore;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "linksStore", {
        get: function () {
            return this._linksStore;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "diagramSettings", {
        get: function () {
            return this._diagramSettings;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "nodesSettings", {
        get: function () {
            return this._nodesSettings;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "linksSettings", {
        get: function () {
            return this._linksSettings;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "portsSettings", {
        get: function () {
            return this._portsSettings;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "callbacks", {
        get: function () {
            return this._callbacks;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "selectionState", {
        get: function () {
            return this._selectionState;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "dragState", {
        get: function () {
            return this._dragState;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RootStore.prototype, "commandExecutor", {
        get: function () {
            return this._commandExecutor;
        },
        enumerable: false,
        configurable: true
    });
    return RootStore;
}());

var RootStoreContext = React__default["default"].createContext(null);
var DiagramContext = mobxReactLite.observer(function (props) {
    var rootStore = React.useMemo(function () { return new RootStore(); }, []);
    React.useEffect(function () {
        rootStore.importSettings(props.settings);
    }, [rootStore, props.settings]);
    React.useEffect(function () {
        var _a, _b, _c, _d;
        rootStore.importState((_b = (_a = props.initState) === null || _a === void 0 ? void 0 : _a.nodes) !== null && _b !== void 0 ? _b : [], (_d = (_c = props.initState) === null || _c === void 0 ? void 0 : _c.links) !== null && _d !== void 0 ? _d : []);
    }, [rootStore, props.initState]);
    React.useEffect(function () {
        if (props.storeRef) {
            props.storeRef.current = rootStore;
        }
    }, [rootStore, props.storeRef]);
    var lastRenderedImportRef = React.useRef(-1);
    React.useLayoutEffect(function () {
        if (rootStore.diagramState.renderImportedRequestId >
            lastRenderedImportRef.current) {
            rootStore.callbacks.importedStateRendered();
            lastRenderedImportRef.current =
                rootStore.diagramState.renderImportedRequestId;
        }
    }, [rootStore.diagramState.renderImportedRequestId]);
    return (React__default["default"].createElement(RootStoreContext.Provider, { value: rootStore }, props.children));
});

var useNotifyRef = function (init) {
    var _a = React.useState(0); _a[0]; var forceUpdate = _a[1];
    var ref = React.useState(function () { return ({
        value: init,
        facade: {
            get current() {
                return ref.value;
            },
            set current(value) {
                var last = ref.value;
                if (last !== value) {
                    ref.value = value;
                    forceUpdate(function (i) { return i + 1; });
                }
            },
        },
    }); })[0];
    return ref.facade;
};

var useLinkUserInteraction = function (linkState) {
    var rootStore = useRootStore();
    var activeRef = useNotifyRef(false);
    var selectionHandledRef = React.useRef(false);
    var selectionTimeoutRef = React.useRef(null);
    var handlers = React.useMemo(function () {
        return linkState instanceof LinkState
            ? {
                onPointerEnter: function () {
                    linkState.hovered = true;
                },
                onPointerLeave: function () {
                    linkState.hovered = false;
                },
                onDragStart: function () {
                    activeRef.current = !rootStore.dragState.isActive;
                    if (activeRef.current) {
                        selectionHandledRef.current = false;
                        if (linkState.isSelectionEnabled) {
                            selectionTimeoutRef.current = global.setTimeout(function () {
                                if (!selectionHandledRef.current) {
                                    selectionHandledRef.current = true;
                                    rootStore.selectionState.switch(linkState);
                                }
                            }, selectDelay);
                        }
                    }
                },
                onDragEnd: function (_a) {
                    var tap = _a.tap, ctrlKey = _a.ctrlKey, shiftKey = _a.shiftKey, altKey = _a.altKey, metaKey = _a.metaKey;
                    if (activeRef.current) {
                        activeRef.current = false;
                        if (selectionTimeoutRef.current) {
                            clearTimeout(selectionTimeoutRef.current);
                        }
                        if (linkState.isSelectionEnabled &&
                            tap &&
                            !selectionHandledRef.current) {
                            selectionHandledRef.current = true;
                            rootStore.selectionState.switch(linkState, !rootStore.diagramSettings.userInteraction.isCallbackMultiselectionActivated(shiftKey, altKey, ctrlKey, metaKey));
                        }
                    }
                },
            }
            : {};
    }, [linkState, rootStore]);
    var bind = react.useGesture(handlers, {
        eventOptions: { passive: false },
        enabled: !rootStore.diagramSettings.userInteraction.arePointerInteractionsDisabled
    });
    return { bind: bind };
};
var selectDelay = 500;

var LinkWrapper = mobxReactLite.observer(function (_a) {
    var link = _a.link;
    var bind = useLinkUserInteraction(link).bind;
    return (React__default["default"].createElement("g", null,
        React__default["default"].createElement(link.componentDefinition.component, { bind: bind, entity: link, settings: link.componentDefinition.settings })));
});

var LinksLayer = mobxReactLite.observer(function (_a) {
    var transform = _a.transform;
    return (React__default["default"].createElement("svg", { className: 'react_fast_diagram_Layer' },
        React__default["default"].createElement(MarkerDefs, null),
        React__default["default"].createElement("g", { style: { transform: transform } },
            React__default["default"].createElement(LinksList, null))));
});
var LinksList = mobxReactLite.observer(function () {
    var linksStore = useRootStore().linksStore;
    return (React__default["default"].createElement(React__default["default"].Fragment, null,
        Array.from(linksStore.links).map(function (_a) {
            _a[0]; var link = _a[1];
            return (React__default["default"].createElement(LinkWrapper, { key: link.id, link: link }));
        }),
        React__default["default"].createElement(LinkWrapper, { key: '__creation__', link: linksStore.linkCreation })));
});
var MarkerDefs = mobxReactLite.observer(function () {
    var linksSettings = useRootStore().linksSettings;
    return (React__default["default"].createElement("defs", null, linksSettings.svgMarkers.map(function (Marker, i) { return (React__default["default"].createElement(Marker, { key: i })); })));
});

var NodesLayer = mobxReactLite.observer(function (_a) {
    var transform = _a.transform;
    return (React__default["default"].createElement("div", { className: 'react_fast_diagram_Layer', style: { transform: transform } },
        React__default["default"].createElement(NodesList, null)));
});
var NodesList = mobxReactLite.observer(function () {
    var nodesStore = useRootStore().nodesStore;
    return (React__default["default"].createElement(React__default["default"].Fragment, null, Array.from(nodesStore.nodes).map(function (_a) {
        _a[0]; var node = _a[1];
        return (React__default["default"].createElement(NodeWrapper, { key: node.id, node: node }));
    })));
});

function useDiagramDragHandlers(cancelEvent) {
    var rootStore = useRootStore();
    var diagramState = rootStore.diagramState;
    var activeRef = useNotifyRef(false);
    var handlers = React.useMemo(function () { return ({
        onDrag: function (_a) {
            var pinching = _a.pinching, delta = _a.delta;
            if (!activeRef.current || pinching) {
                return;
            }
            diagramState.setOffset(addPoints(diagramState.offset, delta));
        },
        onDragStart: function (_a) {
            var event = _a.event, cancel = _a.cancel;
            if (cancelEvent(event)) {
                cancel();
                return;
            }
            // Do not activate so drag will not be performed, but also don't cancel, as it would not be possible to clear selection
            if (!rootStore.diagramSettings.userInteraction.diagramPan) {
                return;
            }
            if (event.buttons !== 1) {
                return;
            }
            activeRef.current = true;
        },
        onDragEnd: function (_a) {
            var tap = _a.tap;
            if (activeRef.current) {
                if (tap) {
                    rootStore.selectionState.unselectAll();
                }
                activeRef.current = false;
            }
        },
    }); }, [activeRef, diagramState, cancelEvent, rootStore]);
    useDiagramCursor(activeRef.current, 'grabbing');
    return handlers;
}

function useDiagramPinchHandlers(cancel) {
    var _a = useRootStore(), diagramState = _a.diagramState, diagramSettings = _a.diagramSettings;
    var activeRef = useNotifyRef(false);
    var pinchState = React.useRef({
        distance: 0,
        origin: [0, 0],
        elementLeftTop: [0, 0],
    });
    var handlers = React.useMemo(function () { return ({
        onPinch: function (_a) {
            var distance = _a.da[0], origin = _a.origin;
            if (!activeRef.current || !diagramState.ref.current || distance <= 0) {
                return;
            }
            var originDiff = diagramSettings.userInteraction.diagramPan
                ? subtractPoints(origin, pinchState.current.origin)
                : [0, 0];
            var originPositionOnElement = subtractPoints(origin, pinchState.current.elementLeftTop);
            diagramState.translateAndZoomInto(originDiff, originPositionOnElement, distance / pinchState.current.distance);
            pinchState.current = {
                distance: distance,
                origin: origin,
                elementLeftTop: pinchState.current.elementLeftTop,
            };
        },
        onPinchStart: function (_a) {
            var distance = _a.da[0], origin = _a.origin, event = _a.event;
            if (!diagramSettings.userInteraction.diagramZoom ||
                cancel(event) ||
                !diagramState.ref.current ||
                distance <= 0) {
                return;
            }
            var rect = diagramState.ref.current.getBoundingClientRect();
            pinchState.current = {
                distance: distance,
                origin: origin,
                elementLeftTop: [rect.left, rect.top],
            };
            activeRef.current = true;
        },
        onPinchEnd: function () { return (activeRef.current = false); },
    }); }, [diagramState.ref.current, activeRef, diagramState, cancel, diagramSettings]);
    return handlers;
}

function useDiagramWheelHandler(state) {
    var _a = useRootStore(), diagramState = _a.diagramState, diagramSettings = _a.diagramSettings;
    var handlers = React.useMemo(function () { return ({
        onWheel: function (_a) {
            var _b = _a.direction; _b[0]; var yDirection = _b[1], event = _a.event;
            if (!diagramState.ref.current ||
                !diagramSettings.userInteraction.diagramZoom)
                return;
            event === null || event === void 0 ? void 0 : event.preventDefault();
            var rect = diagramState.ref.current.getBoundingClientRect();
            var mousePositionOnElement = subtractPoints([event.clientX, event.clientY], [rect.left, rect.top]);
            var factor = 0.9;
            if (yDirection < 0) {
                factor = 1 / factor;
            }
            state.translateAndZoomInto([0, 0], mousePositionOnElement, factor);
        },
    }); }, [diagramState.ref, state, diagramSettings]);
    return handlers;
}

var useDiagramUserInteraction = function () {
    var _a = useRootStore(), diagramState = _a.diagramState, diagramSettings = _a.diagramSettings;
    var cancelGesture = React.useCallback(function (event) { return event.target !== diagramState.ref.current; }, [diagramState.ref]);
    var dragHandlers = useDiagramDragHandlers(cancelGesture);
    var pinchHandlers = useDiagramPinchHandlers(cancelGesture);
    var wheelHandler = useDiagramWheelHandler(diagramState);
    react.useGesture(__assign(__assign(__assign({}, dragHandlers), pinchHandlers), wheelHandler), {
        target: diagramState.ref,
        eventOptions: { passive: false },
        enabled: !diagramSettings.userInteraction.arePointerInteractionsDisabled
    });
};

var BackgroundWrapper = mobxReactLite.observer(function () {
    var _a = useRootStore(), diagramSettings = _a.diagramSettings, diagramState = _a.diagramState;
    return (React__default["default"].createElement("div", { className: 'react_fast_diagram_BackgroundWrapper' },
        React__default["default"].createElement(diagramSettings.backgroundComponentState.component, { diagramOffset: diagramState.offset, diagramZoom: diagramState.zoom, settings: diagramSettings.backgroundComponentState.settings })));
});

var MiniControlWrapper = mobxReactLite.observer(function () {
    var rootStore = useRootStore();
    var minicontrolComponentState = rootStore.diagramSettings.miniControlComponentState;
    return (minicontrolComponentState.component && (React__default["default"].createElement(minicontrolComponentState.component, { rootStore: rootStore, settings: minicontrolComponentState.settings })));
});

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "/* Diagram */\n.react_fast_diagram_DiagramInner {\n  width: 100%;\n  height: 100%;\n  position: relative;\n  overflow: hidden;\n  -moz-user-select: none;\n   -ms-user-select: none;\n       user-select: none;\n  -webkit-user-select: none;\n}\n\n.react_fast_diagram_Layer {\n  position: absolute;\n  /* We cannot set it to 100% of parent (and there is not need in this) because if parent will be smaller than node\n  then browser will try to shrink node */\n  width: 1000px; \n  height: 1000px;\n  top: 0;\n  left: 0;\n  overflow: visible;\n  transform-origin: 0px 0px;\n  /* useGestures hook use targetTouches instead of simply touches, \n  so we should set this property to Movable, otherwise if user put \n  one finger above Movable and another above DiagramInner, the hook \n  will not trigger pinch gesture */\n  pointer-events: none;\n}\n/* Diagram */\n\n/* Node */\n.react_fast_diagram_NodeWrapper {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: -webkit-fit-content;\n  width: -moz-fit-content;\n  width: fit-content;\n  height: -webkit-fit-content;\n  height: -moz-fit-content;\n  height: fit-content;\n  pointer-events: auto;\n}\n\n.react_fast_diagram_NodeDefault {\n  min-width: 10px;\n  min-height: 10px;\n  border-radius: 3px;\n  background-color: white;\n  border: #c2c2c2 solid 1px;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n}\n\n.react_fast_diagram_NodeDefault_Hovered {\n  border: #a5d1fc solid 1px;\n}\n\n.react_fast_diagram_NodeDefault_Selected {\n  border: #7BBDFF solid 1px;\n}\n\n.react_fast_diagram_NodeLabel {\n  padding: 5px 7px;\n  text-align: center;\n  margin: auto;\n}\n/* Node */\n\n/* Background */\n.react_fast_diagram_BackgroundWrapper {\n  height: 100%;\n  width: 100%;\n  pointer-events: none;\n}\n\n.react_fast_diagram_Background {\n  height: 100%;\n  width: 100%;\n}\n/* Background */\n\n/* MiniControl */\n.react_fast_diagram_MiniControl_Default {\n  position: absolute;\n  height: -webkit-fit-content;\n  height: -moz-fit-content;\n  height: fit-content;\n  display: flex;\n  flex-direction: column;\n}\n\n.react_fast_diagram_MiniControl_Btn {\n  background-color: white;\n  border: 1px solid rgb(209, 209, 209);\n  color: black;\n  padding: 2px;\n  font-size: 16px;\n  cursor: pointer;\n  text-align: center;\n}\n\n@media (hover: hover) and (pointer: fine) {\n  .react_fast_diagram_MiniControl_Btn:hover {\n    background-color: rgb(228, 228, 228);\n  }\n}\n/* MiniControl */\n\n/* Port */\n.react_fast_diagram_PortInnerDefault {\n  width: 7px;\n  height: 7px;\n  background-color: white;\n  border: 1px solid #c2c2c2;\n  border-radius: 9999px;\n}\n\n.react_fast_diagram_PortInnerDefault_Hovered {\n  cursor: pointer;\n  border-color: #A0F251;\n}\n\n.react_fast_diagram_PortInnerDefault_Dragging {\n  cursor: pointer;\n  border-color: #A0F251;\n}\n\n.react_fast_diagram_PortInnerDefault_Invalid {\n  cursor: pointer;\n  border-color: #FF7B8F;\n}\n\n.react_fast_diagram_PortInnerDefault_NodeHovered {\n  border-color: #a5d1fc;\n}\n\n.react_fast_diagram_PortInnerDefault_NodeSelected {\n  border-color: #7BBDFF;\n}\n\n/* Port */\n\n/* Link */\n.react_fast_diagram_LinkDefault_Line {  \n  fill: none;\n  stroke-linecap: round;\n  stroke: #c2c2c2;\n  stroke-width: 1px;\n}\n\n.react_fast_diagram_LinkDefault_Line_Selected {\n  stroke: #7BBDFF;\n}\n\n.react_fast_diagram_LinkDefault_Line_Hovered {\n  stroke: #a1d0ff;\n}\n\n.react_fast_diagram_LinkDefault_SecondaryLine {\n  stroke-width: 5px;\n  stroke-opacity: 0;\n  pointer-events: stroke;\n  touch-action: none;\n}\n\n.react_fast_diagram_LinkDefault_SecondaryLine_Hovered {\n  stroke-opacity: 0.22;\n  cursor: pointer;\n}\n/* Link */\n\n/* Drag and drop */\n.react_fast_diagram_DragAndDropContainer {\n  display: flex;\n  flex-direction: column;\n  padding: 20px;\n  gap: 10px;\n  overflow-y: auto;\n  align-items: center;\n}\n\n.react_fast_diagram_DragAndDropItem {\n  touch-action: none;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n  width: -webkit-fit-content;\n  width: -moz-fit-content;\n  width: fit-content;\n  height: -webkit-fit-content;\n  height: -moz-fit-content;\n  height: fit-content;\n}\n\n.react_fast_diagram_DragAndDropItem_Droppable {\n  position: fixed;\n}\n/* Drag and drop */\n\n/* Containers with gap between items */\n.react_fast_diagram_flex_gap {\n  --gap: 12px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n\n.react_fast_diagram_flex_gap_y {\n  flex-direction: column;\n  height: 100%;\n}\n\n.react_fast_diagram_flex_gap_y > * {\n  margin: var(--gap) 0 0 0;\n}\n\n.react_fast_diagram_flex_gap_y > :first-child {\n  margin: 0;\n}\n\n.react_fast_diagram_flex_gap_x {\n  flex-direction: row;\n  width: 100%;\n}\n\n.react_fast_diagram_flex_gap_x > * {\n  margin: 0 0 0 var(--gap);\n}\n\n.react_fast_diagram_flex_gap_x > :first-child {\n  margin: 0;\n}\n/* Containers with gap between items */\n\n/* Utils */\n.react_fast_diagram_touch_action_disabled {\n  touch-action: none;\n}\n/* Utils */\n";
styleInject(css_248z,{"insertAt":"top"});

var DigramInner = mobxReactLite.observer(function (props) {
    var rootStore = useRootStore();
    useDiagramUserInteraction();
    useResizeAction(function () {
        rootStore.diagramState.ref.recalculateSizeAndPosition();
        rootStore.nodesStore.nodes.forEach(function (n) { return n.recalculatePortsOffset(); });
    });
    var offset = rootStore.diagramState.offset;
    var zoom = rootStore.diagramState.zoom;
    var transform = generateTransform(offset, zoom);
    var className = 'react_fast_diagram_DiagramInner';
    if (!rootStore.diagramSettings.userInteraction.arePointerInteractionsDisabled) {
        // Disable touch actions as useGesture library recommends
        className += ' react_fast_diagram_touch_action_disabled';
    }
    return (React__default["default"].createElement("div", { ref: rootStore.diagramState.ref, style: props.diagramStyles, "data-zoom": zoom, className: className },
        React__default["default"].createElement(BackgroundWrapper, null),
        React__default["default"].createElement(LinksLayer, { transform: transform }),
        React__default["default"].createElement(NodesLayer, { transform: transform }),
        props.children,
        React__default["default"].createElement(MiniControlWrapper, null)));
});
function useResizeAction(action) {
    var rootStore = useRootStore();
    React.useEffect(function () {
        window.addEventListener('resize', action);
        return function () { return window.removeEventListener('resize', action); };
    }, [rootStore, action]);
}

function Diagram(props) {
    return (React__default["default"].createElement(DiagramContext, { initState: props.initState, settings: props.settings, storeRef: props.storeRef },
        React__default["default"].createElement(DigramInner, { children: props.children })));
}

function DragAndDropItem(props) {
    var store = useRootStore();
    var _a = React.useState([0, 0]), position = _a[0], setPosition = _a[1];
    var _b = React.useState([0, 0]), translate = _b[0], setTranslate = _b[1];
    var _c = React.useState(false), active = _c[0], setActive = _c[1];
    var diagramRectRef = React.useRef();
    var elementRef = React.useRef(null);
    var cancelledRef = React.useRef(false);
    var getPositionOnDiagram = React.useCallback(function (pointerPosition) {
        if (diagramRectRef.current) {
            var pointOnDiagram = subtractPoints(pointerPosition, [
                diagramRectRef.current.left,
                diagramRectRef.current.top,
            ]);
            if (pointOnDiagram[0] >= 0 &&
                pointOnDiagram[1] >= 0 &&
                pointOnDiagram[0] <= diagramRectRef.current.width &&
                pointOnDiagram[1] <= diagramRectRef.current.height) {
                return multiplyPoint(subtractPoints(pointOnDiagram, store.diagramState.offset), 1 / store.diagramState.zoom);
            }
        }
    }, [diagramRectRef, store]);
    react.useGesture({
        onDrag: function (_a) {
            var _b;
            var movement = _a.movement, xy = _a.xy;
            // Cannot use 'cancel' property provided by the library because the first callbacks
            // after cancelling will have this property set to false
            if (!cancelledRef.current) {
                setTranslate(movement);
                (_b = props.onDrag) === null || _b === void 0 ? void 0 : _b.call(props, {
                    position: getPositionOnDiagram(xy),
                    pointerPosition: xy,
                    store: store,
                });
            }
        },
        onDragStart: function (_a) {
            var _b, _c;
            var xy = _a.xy, cancel = _a.cancel;
            var allowDrag = (_b = props.onDragStart) === null || _b === void 0 ? void 0 : _b.call(props, { pointerPosition: xy, store: store });
            if (allowDrag === false) {
                cancelledRef.current = true;
                cancel();
                return;
            }
            else {
                cancelledRef.current = false;
                diagramRectRef.current = (_c = store.diagramState.ref.current) === null || _c === void 0 ? void 0 : _c.getBoundingClientRect();
                setPosition(xy);
                setActive(true);
            }
        },
        onDragEnd: function (_a) {
            var _b;
            var xy = _a.xy;
            if (!cancelledRef.current) {
                setActive(false);
                setTranslate([0, 0]);
                (_b = props.onDrop) === null || _b === void 0 ? void 0 : _b.call(props, {
                    position: getPositionOnDiagram(xy),
                    pointerPosition: xy,
                    store: store,
                });
            }
        },
    }, {
        target: elementRef,
        eventOptions: { passive: false },
    });
    return (React__default["default"].createElement("div", { className: 'react_fast_diagram_DragAndDropItem', ref: elementRef },
        props.draggable,
        React__default["default"].createElement("div", { className: 'react_fast_diagram_DragAndDropItem_Droppable', style: {
                transform: "translate(calc(" + translate[0] + "px - 50%), calc(" + translate[1] + "px - 50%))",
                opacity: active ? 1 : 0,
                pointerEvents: active ? 'auto' : 'none',
                left: position[0],
                top: position[1],
            } }, props.droppable ? props.droppable : props.draggable)));
}
function createNodeOnDrop(node) {
    return function (event) {
        // Check if drop occured above the diagram
        if (event.position) {
            event.store.commandExecutor.execute(addNodeCommand(__assign(__assign({}, node), { position: event.position })));
        }
    };
}

function DragAndDropContainer(props) {
    var _a;
    var className = React.useMemo(function () {
        return combineArrays(['react_fast_diagram_DragAndDropContainer'], props === null || props === void 0 ? void 0 : props.classes).join(' ');
    }, [props.classes]);
    return (React__default["default"].createElement("div", { className: className, style: props.style }, (_a = props.items) === null || _a === void 0 ? void 0 : _a.map(function (item, index) { return (React__default["default"].createElement(DragAndDropItem, __assign({ key: index }, item))); })));
}

var positionValues = ['left', 'top', 'right', 'bottom'];

var PortsContainer = mobxReactLite.observer(function (_a) {
    var position = _a.position, ports = _a.ports, style = _a.style, gapBetweenPorts = _a.gapBetweenPorts, offsetFromOriginPosition = _a.offsetFromOriginPosition;
    var portsModified = React.useMemo(function () {
        return ports &&
            ports.map(function (p) {
                return (__assign({ linkDirection: positionToDirection[position] }, p));
            });
    }, [position, ports]);
    if (!portsModified || portsModified.length === 0)
        return null;
    var className = 'react_fast_diagram_flex_gap ';
    if (position === 'top' || position === 'bottom') {
        className += 'react_fast_diagram_flex_gap_x';
    }
    else {
        className += 'react_fast_diagram_flex_gap_y';
    }
    var positionStyle = {
        position: 'absolute',
        left: position === 'left' ? 0 : undefined,
        top: position === 'left' || position === 'right' || position === 'top'
            ? 0
            : undefined,
        right: position === 'right' ? 0 : undefined,
        bottom: position === 'bottom' ? 0 : undefined,
        height: position === 'left' || position === 'right' ? '100%' : undefined,
        width: position === 'top' || position === 'bottom' ? '100%' : undefined,
    };
    var offsetFromOriginPositionStyle = {};
    if (offsetFromOriginPosition && positionValues.includes(position)) {
        offsetFromOriginPositionStyle[position] = -offsetFromOriginPosition;
    }
    return (React__default["default"].createElement("div", { className: className, style: __assign(__assign(__assign({ 
            // @ts-ignore
            '--gap': gapBetweenPorts }, style), positionStyle), offsetFromOriginPositionStyle) }, portsModified &&
        portsModified.map(function (port) { return React__default["default"].createElement(Port, __assign({}, port, { key: port.id })); })));
});
var positionToDirection = {
    left: 'left',
    top: 'up',
    right: 'right',
    bottom: 'down',
};
function createPortsContainer(settings) {
    return function (props) { return (React__default["default"].createElement(PortsContainer, __assign({}, __assign(__assign({}, defaultPortsContainerSettings), settings), props))); };
}
var defaultPortsContainerSettings = {
    gapBetweenPorts: '8px',
};

var useDiagram = function (initState, settings) {
    var storeRef = useNotifyRef(null);
    var obj = React.useMemo(function () { return ({
        Diagram: function () { return (React__default["default"].createElement(Diagram, { storeRef: storeRef, initState: initState, settings: settings })); },
        storeRef: storeRef,
    }); }, []);
    return obj;
};

function straightLinkPathConstructor(source, target) {
    var path = "M " + source.point[0] + " " + source.point[1] + ", " + target.point[0] + " " + target.point[1];
    return path;
}
function createStraightLinkPathConstructor() {
    return straightLinkPathConstructor;
}

exports.BackgroundWrapper = BackgroundWrapper;
exports.Button = Button;
exports.COMPONENT_DEFAULT_TYPE = COMPONENT_DEFAULT_TYPE;
exports.Callbacks = Callbacks;
exports.CommandExecutor = CommandExecutor;
exports.CopyIcon = CopyIcon;
exports.DISABLE_NODE_USER_INTERACTION_CLASS = DISABLE_NODE_USER_INTERACTION_CLASS;
exports.Diagram = Diagram;
exports.DiagramContext = DiagramContext;
exports.DiagramSettings = DiagramSettings;
exports.DiagramState = DiagramState;
exports.DigramInner = DigramInner;
exports.DragAndDropContainer = DragAndDropContainer;
exports.DragAndDropItem = DragAndDropItem;
exports.DragState = DragState;
exports.ENABLE_NODE_USER_INTERACTION_CLASS = ENABLE_NODE_USER_INTERACTION_CLASS;
exports.FilterCenterFocusIcon = FilterCenterFocusIcon;
exports.HtmlElementRefState = HtmlElementRefState;
exports.LINK_CREATION_COMPONENT_TYPE = LINK_CREATION_COMPONENT_TYPE;
exports.LinkCreationState = LinkCreationState;
exports.LinkDefault = LinkDefault;
exports.LinkPointEndpointState = LinkPointEndpointState;
exports.LinkPortEndpointState = LinkPortEndpointState;
exports.LinkState = LinkState;
exports.LinkWrapper = LinkWrapper;
exports.LinksLayer = LinksLayer;
exports.LinksSettings = LinksSettings;
exports.LinksStore = LinksStore;
exports.LockIcon = LockIcon;
exports.MiniControlWrapper = MiniControlWrapper;
exports.NodeContext = NodeContext;
exports.NodeLabel = NodeLabel;
exports.NodeState = NodeState;
exports.NodeWrapper = NodeWrapper;
exports.NodesLayer = NodesLayer;
exports.NodesSettings = NodesSettings;
exports.NodesStore = NodesStore;
exports.Port = Port;
exports.PortState = PortState;
exports.PortsSettings = PortsSettings;
exports.RootStore = RootStore;
exports.RootStoreContext = RootStoreContext;
exports.RubbishBinIcon = RubbishBinIcon;
exports.SelectionState = SelectionState;
exports.UnlockIcon = UnlockIcon;
exports.UserInteractionSettings = UserInteractionSettings;
exports.VisualComponentState = VisualComponentState;
exports.VisualComponentWithDefault = VisualComponentWithDefault;
exports.VisualComponents = VisualComponents;
exports.addNodeCommand = addNodeCommand;
exports.addPoints = addPoints;
exports.arePointsEqual = arePointsEqual;
exports.areTransformationsEqual = areTransformationsEqual;
exports.canDragGestureBeTapInstead = canDragGestureBeTapInstead;
exports.clampValue = clampValue;
exports.cloneSelectedNodesCommand = cloneSelectedNodesCommand;
exports.combineArrays = combineArrays;
exports.commandC = commandC;
exports.commandM = commandM;
exports.coordinateFromPoint = coordinateFromPoint;
exports.createArrowMarker = createArrowMarker;
exports.createCircleMarker = createCircleMarker;
exports.createCrossesImageGenerator = createCrossesImageGenerator;
exports.createCurvedLinkPathConstructor = createCurvedLinkPathConstructor;
exports.createDefaultMiniControl = createDefaultMiniControl;
exports.createDotsImageGenerator = createDotsImageGenerator;
exports.createFullPortId = createFullPortId;
exports.createGridImageGenerator = createGridImageGenerator;
exports.createInputHorizontalNode = createInputHorizontalNode;
exports.createInputOutputHorizontalNode = createInputOutputHorizontalNode;
exports.createInputOutputVerticalNode = createInputOutputVerticalNode;
exports.createInputVerticalNode = createInputVerticalNode;
exports.createLinkDefault = createLinkDefault;
exports.createLinkPath = createLinkPath;
exports.createNode = createNode;
exports.createNodeOnDrop = createNodeOnDrop;
exports.createOutputHorizontalNode = createOutputHorizontalNode;
exports.createOutputVerticalNode = createOutputVerticalNode;
exports.createPortInnerDefault = createPortInnerDefault;
exports.createPortsContainer = createPortsContainer;
exports.createStarNode = createStarNode;
exports.createStraightLinkPathConstructor = createStraightLinkPathConstructor;
exports.createSvgBackground = createSvgBackground;
exports.createVector = createVector;
exports.deepCopy = deepCopy;
exports.defaultLinkMainLineClasses = defaultLinkMainLineClasses;
exports.defaultLinkSecondaryLineClasses = defaultLinkSecondaryLineClasses;
exports.defaultNodeClasses = defaultNodeClasses;
exports.defaultPortInnerClasses = defaultPortInnerClasses;
exports.distanceBetweenPoints = distanceBetweenPoints;
exports.errorResult = errorResult;
exports.errorValueResult = errorValueResult;
exports.eventPathContainsClass = eventPathContainsClass;
exports.generateTransform = generateTransform;
exports.getDegree = getDegree;
exports.getRadian = getRadian;
exports.guid = guid;
exports.guidForcedUniqueness = guidForcedUniqueness;
exports.isBoolean = isBoolean;
exports.isError = isError;
exports.isNumber = isNumber;
exports.isObject = isObject;
exports.isPoint = isPoint;
exports.isSuccess = isSuccess;
exports.linkPortEndpointsEquals = linkPortEndpointsEquals;
exports.multiplyPoint = multiplyPoint;
exports.portPositionValues = portPositionValues;
exports.positionValues = positionValues;
exports.removeSelectedCommand = removeSelectedCommand;
exports.removeSelectedLinksCommand = removeSelectedLinksCommand;
exports.removeSelectedNodesCommand = removeSelectedNodesCommand;
exports.roundPoint = roundPoint;
exports.subtractPoints = subtractPoints;
exports.successResult = successResult;
exports.successValueResult = successValueResult;
exports.useCursor = useCursor;
exports.useDiagram = useDiagram;
exports.useDiagramCursor = useDiagramCursor;
exports.useDiagramDragHandlers = useDiagramDragHandlers;
exports.useDiagramPinchHandlers = useDiagramPinchHandlers;
exports.useDiagramUserInteraction = useDiagramUserInteraction;
exports.useDiagramWheelHandler = useDiagramWheelHandler;
exports.useLinkUserInteraction = useLinkUserInteraction;
exports.useNodeUserInteraction = useNodeUserInteraction;
exports.useNotifyRef = useNotifyRef;
exports.usePortUserInteraction = usePortUserInteraction;
exports.useRelativePositionStyles = useRelativePositionStyles;
exports.useRootStore = useRootStore;
exports.useStyling = useStyling;
//# sourceMappingURL=index.js.map
